[Libreoffice-commits] core.git: cui/source filter/source include/svx sc/source sd/source svx/source sw/source

Radu Ioan ioan.radu.g at gmail.com
Sun Nov 23 09:16:45 PST 2014


 cui/source/tabpages/tpline.cxx                        |   27 +++++++++---------
 cui/source/tabpages/tplnedef.cxx                      |   15 ++++++----
 cui/source/tabpages/tplneend.cxx                      |    2 -
 filter/source/msfilter/msdffimp.cxx                   |    6 ++--
 filter/source/msfilter/svdfppt.cxx                    |   15 +++++-----
 include/svx/xenum.hxx                                 |    1 
 include/svx/xlineit0.hxx                              |    5 ++-
 sc/source/filter/excel/xiescher.cxx                   |   18 ++++++------
 sd/source/core/drawdoc4.cxx                           |   27 +++++++++---------
 sd/source/core/stlpool.cxx                            |   12 ++++----
 sd/source/filter/ppt/pptin.cxx                        |    5 ++-
 sd/source/ui/animations/motionpathtag.cxx             |    2 -
 sd/source/ui/dlg/morphdlg.cxx                         |    7 ++--
 sd/source/ui/func/fucon3d.cxx                         |    6 ++--
 sd/source/ui/func/fuexpand.cxx                        |    2 -
 sd/source/ui/func/fumorph.cxx                         |   13 ++++----
 sd/source/ui/func/fusumry.cxx                         |    2 -
 sd/source/ui/view/DocumentRenderer.cxx                |    6 ++--
 sd/source/ui/view/drviews9.cxx                        |    7 ++--
 svx/source/customshapes/EnhancedCustomShape2d.cxx     |   10 +++---
 svx/source/customshapes/EnhancedCustomShape3d.cxx     |   12 ++++----
 svx/source/customshapes/EnhancedCustomShapeEngine.cxx |    2 -
 svx/source/dialog/dlgctl3d.cxx                        |   12 ++++----
 svx/source/dialog/dlgctrl.cxx                         |    7 ++--
 svx/source/engine3d/extrud3d.cxx                      |    2 -
 svx/source/engine3d/float3d.cxx                       |    6 ++--
 svx/source/engine3d/lathe3d.cxx                       |    2 -
 svx/source/engine3d/view3d.cxx                        |    8 ++---
 svx/source/engine3d/view3d1.cxx                       |    3 +-
 svx/source/sdr/attribute/sdrformtextattribute.cxx     |    5 ++-
 svx/source/sdr/contact/viewcontactofsdrcaptionobj.cxx |    2 -
 svx/source/sdr/primitive2d/sdrattributecreator.cxx    |    6 ++--
 svx/source/sdr/properties/measureproperties.cxx       |    3 --
 svx/source/sdr/properties/textproperties.cxx          |    4 +-
 svx/source/sidebar/line/LinePropertyPanel.cxx         |   18 ++++++------
 svx/source/svdraw/svdcrtv.cxx                         |    6 ++--
 svx/source/svdraw/svdedtv2.cxx                        |   10 +++---
 svx/source/svdraw/svdfmtf.cxx                         |   26 ++++++++---------
 svx/source/svdraw/svdibrow.cxx                        |    6 ++--
 svx/source/svdraw/svdoashp.cxx                        |    4 +-
 svx/source/svdraw/svdoattr.cxx                        |    4 +-
 svx/source/svdraw/svdobj.cxx                          |   16 +++++-----
 svx/source/svdraw/svdocirc.cxx                        |    6 ++--
 svx/source/svdraw/svdograf.cxx                        |    2 -
 svx/source/svdraw/svdoole2.cxx                        |    4 +-
 svx/source/svdraw/svdotxtr.cxx                        |    4 +-
 svx/source/svdraw/svdxcgv.cxx                         |    4 +-
 svx/source/tbxctrls/colrctrl.cxx                      |    8 ++---
 svx/source/tbxctrls/itemwin.cxx                       |    8 ++---
 svx/source/tbxctrls/linectrl.cxx                      |   13 ++++----
 svx/source/unodraw/UnoGraphicExporter.cxx             |    2 -
 svx/source/unodraw/unoshape.cxx                       |    2 -
 svx/source/xoutdev/xattr.cxx                          |    6 ++--
 sw/source/filter/ww8/docxattributeoutput.cxx          |    5 ++-
 sw/source/filter/ww8/ww8graf.cxx                      |    8 ++---
 55 files changed, 221 insertions(+), 203 deletions(-)

New commits:
commit 7528b498b634f0d96a710afc7faf20299cc5792d
Author: Radu Ioan <ioan.radu.g at gmail.com>
Date:   Fri Nov 21 20:48:11 2014 +0200

    fdo#85486 - Clean up unnecessary enumerations from xenum.hxx
    
     Removed XLineStyle
    
    Reviewed on:
    	https://gerrit.libreoffice.org/13029
    
    Change-Id: I583575a04988ccf932374e411672ba14a3f3cb2f

diff --git a/cui/source/tabpages/tpline.cxx b/cui/source/tabpages/tpline.cxx
index ae9395d..5bf1028 100644
--- a/cui/source/tabpages/tpline.cxx
+++ b/cui/source/tabpages/tpline.cxx
@@ -62,6 +62,7 @@
 #define MN_SYMBOLS_AUTO    2
 #define MN_GALLERY_ENTRY 100
 
+using namespace com::sun::star;
 
 // static ----------------------------------------------------------------
 
@@ -99,7 +100,7 @@ SvxLineTabPage::SvxLineTabPage
     bObjSelected( false ),
 
     pXPool              ( static_cast<XOutdevItemPool*>(rInAttrs.GetPool()) ),
-    aXLStyle            ( XLINE_DASH ),
+    aXLStyle            ( drawing::LineStyle_DASH ),
     aXWidth             ( 1 ),
     aXDash              ( OUString(), XDash( XDASH_RECT, 3, 7, 2, 40, 15 ) ),
     aXColor             ( OUString(), COL_LIGHTRED ),
@@ -689,12 +690,12 @@ bool SvxLineTabPage::FillItemSet( SfxItemSet* rAttrs )
             boost::scoped_ptr<XLineStyleItem> pStyleItem;
 
             if( nPos == 0 )
-                pStyleItem.reset(new XLineStyleItem( XLINE_NONE ));
+                pStyleItem.reset(new XLineStyleItem( drawing::LineStyle_NONE ));
             else if( nPos == 1 )
-                pStyleItem.reset(new XLineStyleItem( XLINE_SOLID ));
+                pStyleItem.reset(new XLineStyleItem( drawing::LineStyle_SOLID ));
             else
             {
-                pStyleItem.reset(new XLineStyleItem( XLINE_DASH ));
+                pStyleItem.reset(new XLineStyleItem( drawing::LineStyle_DASH ));
 
                 // For added security
                 if( pDashList->Count() > (long) ( nPos - 2 ) )
@@ -965,15 +966,15 @@ bool SvxLineTabPage::FillXLSet_Impl()
 
     if( m_pLbLineStyle->GetSelectEntryPos() == LISTBOX_ENTRY_NOTFOUND )
     {
-        rXLSet.Put( XLineStyleItem( XLINE_NONE ) );
+        rXLSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
     }
     else if( m_pLbLineStyle->IsEntryPosSelected( 0 ) )
-        rXLSet.Put( XLineStyleItem( XLINE_NONE ) );
+        rXLSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
     else if( m_pLbLineStyle->IsEntryPosSelected( 1 ) )
-        rXLSet.Put( XLineStyleItem( XLINE_SOLID ) );
+        rXLSet.Put( XLineStyleItem( drawing::LineStyle_SOLID ) );
     else
     {
-        rXLSet.Put( XLineStyleItem( XLINE_DASH ) );
+        rXLSet.Put( XLineStyleItem( drawing::LineStyle_DASH ) );
 
         nPos = m_pLbLineStyle->GetSelectEntryPos();
         if( nPos != LISTBOX_ENTRY_NOTFOUND )
@@ -1086,7 +1087,7 @@ bool SvxLineTabPage::FillXLSet_Impl()
 
 void SvxLineTabPage::Reset( const SfxItemSet* rAttrs )
 {
-    XLineStyle  eXLS; // XLINE_NONE, XLINE_SOLID, XLINE_DASH
+    drawing::LineStyle  eXLS; // drawing::LineStyle_NONE, drawing::LineStyle_SOLID, drawing::LineStyle_DASH
 
     // Line style
     const SfxPoolItem *pPoolItem;
@@ -1213,18 +1214,18 @@ void SvxLineTabPage::Reset( const SfxItemSet* rAttrs )
 
     if( rAttrs->GetItemState( XATTR_LINESTYLE ) != SfxItemState::DONTCARE )
     {
-        eXLS = (XLineStyle) static_cast<const XLineStyleItem&>( rAttrs->Get( XATTR_LINESTYLE ) ).GetValue();
+        eXLS = (drawing::LineStyle) static_cast<const XLineStyleItem&>( rAttrs->Get( XATTR_LINESTYLE ) ).GetValue();
 
         switch( eXLS )
         {
-            case XLINE_NONE:
+            case drawing::LineStyle_NONE:
                 m_pLbLineStyle->SelectEntryPos( 0 );
                 break;
-            case XLINE_SOLID:
+            case drawing::LineStyle_SOLID:
                 m_pLbLineStyle->SelectEntryPos( 1 );
                 break;
 
-            case XLINE_DASH:
+            case drawing::LineStyle_DASH:
                 m_pLbLineStyle->SetNoSelection();
                 m_pLbLineStyle->SelectEntry( static_cast<const XLineDashItem&>( rAttrs->Get( XATTR_LINEDASH ) ).GetName() );
                 break;
diff --git a/cui/source/tabpages/tplnedef.cxx b/cui/source/tabpages/tplnedef.cxx
index 2c446c1..c31c811 100644
--- a/cui/source/tabpages/tplnedef.cxx
+++ b/cui/source/tabpages/tplnedef.cxx
@@ -46,6 +46,9 @@
 
 #define XOUT_WIDTH    150
 
+using namespace com::sun::star;
+
+
 SvxLineDefTabPage::SvxLineDefTabPage
 (
     vcl::Window* pParent,
@@ -60,7 +63,7 @@ SvxLineDefTabPage::SvxLineDefTabPage
     bObjSelected    ( false ),
 
     pXPool              ( static_cast<XOutdevItemPool*>(rInAttrs.GetPool()) ),
-    aXLStyle            ( XLINE_DASH ),
+    aXLStyle            ( drawing::LineStyle_DASH ),
     aXWidth             ( XOUT_WIDTH ),
     aXDash              ( OUString(), XDash( XDASH_RECT, 3, 7, 2, 40, 15 ) ),
     aXColor             ( OUString(), COL_BLACK ),
@@ -267,7 +270,7 @@ bool SvxLineDefTabPage::FillItemSet( SfxItemSet* rAttrs )
             FillDash_Impl();
 
             OUString aString( m_pLbLineStyles->GetSelectEntry() );
-            rAttrs->Put( XLineStyleItem( XLINE_DASH ) );
+            rAttrs->Put( XLineStyleItem( drawing::LineStyle_DASH ) );
             rAttrs->Put( XLineDashItem( aString, aDash ) );
         }
     }
@@ -280,16 +283,16 @@ void SvxLineDefTabPage::Reset( const SfxItemSet* rAttrs )
 {
     if( rAttrs->GetItemState( GetWhich( XATTR_LINESTYLE ) ) != SfxItemState::DONTCARE )
     {
-        XLineStyle eXLS = (XLineStyle) static_cast<const XLineStyleItem&>( rAttrs->Get( GetWhich( XATTR_LINESTYLE ) ) ).GetValue();
+        drawing::LineStyle eXLS = (drawing::LineStyle) static_cast<const XLineStyleItem&>( rAttrs->Get( GetWhich( XATTR_LINESTYLE ) ) ).GetValue();
 
         switch( eXLS )
         {
-            case XLINE_NONE:
-            case XLINE_SOLID:
+            case drawing::LineStyle_NONE:
+            case drawing::LineStyle_SOLID:
                 m_pLbLineStyles->SelectEntryPos( 0 );
                 break;
 
-            case XLINE_DASH:
+            case drawing::LineStyle_DASH:
             {
                 const XLineDashItem& rDashItem = static_cast<const XLineDashItem&>( rAttrs->Get( XATTR_LINEDASH ) );
                 aDash = rDashItem.GetDashValue();
diff --git a/cui/source/tabpages/tplneend.cxx b/cui/source/tabpages/tplneend.cxx
index ddff877..54d1e71 100644
--- a/cui/source/tabpages/tplneend.cxx
+++ b/cui/source/tabpages/tplneend.cxx
@@ -63,7 +63,7 @@ SvxLineEndDefTabPage::SvxLineEndDefTabPage
     bObjSelected        ( false ),
 
     pXPool              ( static_cast<XOutdevItemPool*>(rInAttrs.GetPool()) ),
-    aXLStyle            ( XLINE_SOLID ),
+    aXLStyle            ( com::sun::star::drawing::LineStyle_SOLID ),
     aXWidth             ( XOUT_WIDTH ),
     aXColor             ( OUString(), COL_BLACK ),
     aXLineAttr          ( pXPool ),
diff --git a/filter/source/msfilter/msdffimp.cxx b/filter/source/msfilter/msdffimp.cxx
index 466faf6..679c40a 100644
--- a/filter/source/msfilter/msdffimp.cxx
+++ b/filter/source/msfilter/msdffimp.cxx
@@ -922,7 +922,7 @@ void DffPropertyReader::ApplyLineAttributes( SfxItemSet& rSet, const MSO_SPT eSh
 
         MSO_LineDashing eLineDashing = (MSO_LineDashing)GetPropertyValue( DFF_Prop_lineDashing, mso_lineSolid );
         if ( eLineDashing == mso_lineSolid )
-            rSet.Put(XLineStyleItem( XLINE_SOLID ) );
+            rSet.Put(XLineStyleItem( drawing::LineStyle_SOLID ) );
         else
         {
             XDashStyle  eDash = XDASH_RECT;
@@ -982,7 +982,7 @@ void DffPropertyReader::ApplyLineAttributes( SfxItemSet& rSet, const MSO_SPT eSh
             }
 
             rSet.Put( XLineDashItem( OUString(), XDash( eDash, nDots, nDotLen, nDashes, nDashLen, nDistance ) ) );
-            rSet.Put( XLineStyleItem( XLINE_DASH ) );
+            rSet.Put( XLineStyleItem( drawing::LineStyle_DASH ) );
         }
         rSet.Put( XLineColorItem( OUString(), rManager.MSO_CLR_ToColor( GetPropertyValue( DFF_Prop_lineColor ), DFF_Prop_lineColor ) ) );
         if ( IsProperty( DFF_Prop_lineOpacity ) )
@@ -1050,7 +1050,7 @@ void DffPropertyReader::ApplyLineAttributes( SfxItemSet& rSet, const MSO_SPT eSh
         }
     }
     else
-        rSet.Put( XLineStyleItem( XLINE_NONE ) );
+        rSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
 }
 
 struct ShadeColor
diff --git a/filter/source/msfilter/svdfppt.cxx b/filter/source/msfilter/svdfppt.cxx
index d0b2103..6a80926 100644
--- a/filter/source/msfilter/svdfppt.cxx
+++ b/filter/source/msfilter/svdfppt.cxx
@@ -1049,7 +1049,7 @@ SdrObject* SdrEscherImport::ProcessObj( SvStream& rSt, DffObjData& rObjData, voi
                     pTObj->SetMergedItemSet( aSet );
                     if ( pRet )
                     {
-                        pTObj->SetMergedItem( XLineStyleItem( XLINE_NONE ) );
+                        pTObj->SetMergedItem( XLineStyleItem( drawing::LineStyle_NONE ) );
                         pTObj->SetMergedItem( XFillStyleItem( drawing::FillStyle_NONE ) );
                     }
                     if ( bVerticalText )
@@ -2975,7 +2975,7 @@ SdrObject* SdrPowerPointImport::ImportPageBackgroundObject( const SdrPage& rPage
             pSet.reset(new SfxItemSet( pSdrModel->GetItemPool() ));
             pSet->Put( XFillStyleItem( drawing::FillStyle_NONE ) );
         }
-        pSet->Put( XLineStyleItem( XLINE_NONE ) );
+        pSet->Put( XLineStyleItem( drawing::LineStyle_NONE ) );
         Rectangle aRect( rPage.GetLftBorder(), rPage.GetUppBorder(), rPage.GetWdt()-rPage.GetRgtBorder(), rPage.GetHgt()-rPage.GetLwrBorder() );
         pRet = new SdrRectObj( aRect );
         pRet->SetModel( pSdrModel );
@@ -7368,22 +7368,23 @@ void ApplyCellLineAttributes( const SdrObject* pLine, Reference< XTable >& xTabl
     try
     {
         SfxItemSet aSet( pLine->GetMergedItemSet() );
-        XLineStyle eLineStyle(static_cast<const XLineStyleItem&>(pLine->GetMergedItem( XATTR_LINESTYLE )).GetValue());
+        drawing::LineStyle eLineStyle(static_cast<const XLineStyleItem&>(pLine->GetMergedItem( XATTR_LINESTYLE )).GetValue());
         com::sun::star::table::BorderLine2 aBorderLine;
         switch( eLineStyle )
         {
-            case XLINE_DASH :
-            case XLINE_SOLID :
+            case drawing::LineStyle_DASH :
+            case drawing::LineStyle_SOLID :
                 {
                     Color aLineColor( static_cast<const XLineColorItem&>(pLine->GetMergedItem( XATTR_LINECOLOR )).GetColorValue() );
                     aBorderLine.Color = aLineColor.GetColor();
                     // Avoid width = 0, the min value should be 1.
                     sal_Int32 nLineWidth = std::max(sal_Int32(1), static_cast<const XLineWidthItem&>(pLine->GetMergedItem(XATTR_LINEWIDTH)) .GetValue() / 4);
                     aBorderLine.LineWidth = static_cast< sal_Int16 >( nLineWidth );
-                    aBorderLine.LineStyle = eLineStyle == XLINE_SOLID ? table::BorderLineStyle::SOLID : table::BorderLineStyle::DASHED;
+                    aBorderLine.LineStyle = eLineStyle == drawing::LineStyle_SOLID ? table::BorderLineStyle::SOLID : table::BorderLineStyle::DASHED;
                 }
                 break;
-            case XLINE_NONE :
+            default:
+            case drawing::LineStyle_NONE :
                 {
                     aBorderLine.LineWidth = 0;
                     aBorderLine.LineStyle = table::BorderLineStyle::NONE;
diff --git a/include/svx/xenum.hxx b/include/svx/xenum.hxx
index 2f76110..6becd2a 100644
--- a/include/svx/xenum.hxx
+++ b/include/svx/xenum.hxx
@@ -20,7 +20,6 @@
 #ifndef INCLUDED_SVX_XENUM_HXX
 #define INCLUDED_SVX_XENUM_HXX
 
-enum XLineStyle         { XLINE_NONE, XLINE_SOLID, XLINE_DASH };
 enum XDashStyle         { XDASH_RECT, XDASH_ROUND, XDASH_RECTRELATIVE,
                           XDASH_ROUNDRELATIVE };
 enum XGradientStyle     { XGRAD_LINEAR, XGRAD_AXIAL, XGRAD_RADIAL,
diff --git a/include/svx/xlineit0.hxx b/include/svx/xlineit0.hxx
index f0cb2aa..d26c530 100644
--- a/include/svx/xlineit0.hxx
+++ b/include/svx/xlineit0.hxx
@@ -26,12 +26,13 @@
 // class LineStyleItem
 
 #include <svx/svxdllapi.h>
+#include <com/sun/star/drawing/LineStyle.hpp>
 
 class SVX_DLLPUBLIC XLineStyleItem : public SfxEnumItem
 {
 public:
                             TYPEINFO_OVERRIDE();
-                            XLineStyleItem(XLineStyle = XLINE_SOLID);
+                            XLineStyleItem(com::sun::star::drawing::LineStyle = com::sun::star::drawing::LineStyle_SOLID);
                             XLineStyleItem(SvStream& rIn);
     virtual SfxPoolItem*    Clone(SfxItemPool* pPool = 0) const SAL_OVERRIDE;
     virtual SfxPoolItem*    Create(SvStream& rIn, sal_uInt16 nVer) const SAL_OVERRIDE;
@@ -44,7 +45,7 @@ public:
                                     SfxMapUnit ePresMetric,
                                     OUString &rText, const IntlWrapper * = 0 ) const SAL_OVERRIDE;
     virtual sal_uInt16          GetValueCount() const SAL_OVERRIDE;
-    XLineStyle              GetValue() const { return (XLineStyle) SfxEnumItem::GetValue(); }
+    css::drawing::LineStyle     GetValue() const { return (com::sun::star::drawing::LineStyle) SfxEnumItem::GetValue(); }
 };
 
 #endif
diff --git a/sc/source/filter/excel/xiescher.cxx b/sc/source/filter/excel/xiescher.cxx
index bf5ca8a..bc25d5a 100644
--- a/sc/source/filter/excel/xiescher.cxx
+++ b/sc/source/filter/excel/xiescher.cxx
@@ -626,38 +626,38 @@ void XclImpDrawObjBase::ConvertLineStyle( SdrObject& rSdrObj, const XclObjLineDa
         {
             default:
             case EXC_OBJ_LINE_SOLID:
-                rSdrObj.SetMergedItem( XLineStyleItem( XLINE_SOLID ) );
+                rSdrObj.SetMergedItem( XLineStyleItem( drawing::LineStyle_SOLID ) );
             break;
             case EXC_OBJ_LINE_DASH:
-                rSdrObj.SetMergedItem( XLineStyleItem( XLINE_DASH ) );
+                rSdrObj.SetMergedItem( XLineStyleItem( drawing::LineStyle_DASH ) );
                 rSdrObj.SetMergedItem( XLineDashItem( EMPTY_OUSTRING, XDash( XDASH_RECT, 0, nDotLen, 1, nDashLen, nDist ) ) );
             break;
             case EXC_OBJ_LINE_DOT:
-                rSdrObj.SetMergedItem( XLineStyleItem( XLINE_DASH ) );
+                rSdrObj.SetMergedItem( XLineStyleItem( drawing::LineStyle_DASH ) );
                 rSdrObj.SetMergedItem( XLineDashItem( EMPTY_OUSTRING, XDash( XDASH_RECT, 1, nDotLen, 0, nDashLen, nDist ) ) );
             break;
             case EXC_OBJ_LINE_DASHDOT:
-                rSdrObj.SetMergedItem( XLineStyleItem( XLINE_DASH ) );
+                rSdrObj.SetMergedItem( XLineStyleItem( drawing::LineStyle_DASH ) );
                 rSdrObj.SetMergedItem( XLineDashItem( EMPTY_OUSTRING, XDash( XDASH_RECT, 1, nDotLen, 1, nDashLen, nDist ) ) );
             break;
             case EXC_OBJ_LINE_DASHDOTDOT:
-                rSdrObj.SetMergedItem( XLineStyleItem( XLINE_DASH ) );
+                rSdrObj.SetMergedItem( XLineStyleItem( drawing::LineStyle_DASH ) );
                 rSdrObj.SetMergedItem( XLineDashItem( EMPTY_OUSTRING, XDash( XDASH_RECT, 2, nDotLen, 1, nDashLen, nDist ) ) );
             break;
             case EXC_OBJ_LINE_MEDTRANS:
-                rSdrObj.SetMergedItem( XLineStyleItem( XLINE_SOLID ) );
+                rSdrObj.SetMergedItem( XLineStyleItem( drawing::LineStyle_SOLID ) );
                 rSdrObj.SetMergedItem( XLineTransparenceItem( 50 ) );
             break;
             case EXC_OBJ_LINE_DARKTRANS:
-                rSdrObj.SetMergedItem( XLineStyleItem( XLINE_SOLID ) );
+                rSdrObj.SetMergedItem( XLineStyleItem( drawing::LineStyle_SOLID ) );
                 rSdrObj.SetMergedItem( XLineTransparenceItem( 25 ) );
             break;
             case EXC_OBJ_LINE_LIGHTTRANS:
-                rSdrObj.SetMergedItem( XLineStyleItem( XLINE_SOLID ) );
+                rSdrObj.SetMergedItem( XLineStyleItem( drawing::LineStyle_SOLID ) );
                 rSdrObj.SetMergedItem( XLineTransparenceItem( 75 ) );
             break;
             case EXC_OBJ_LINE_NONE:
-                rSdrObj.SetMergedItem( XLineStyleItem( XLINE_NONE ) );
+                rSdrObj.SetMergedItem( XLineStyleItem( drawing::LineStyle_NONE ) );
             break;
         }
     }
diff --git a/sd/source/core/drawdoc4.cxx b/sd/source/core/drawdoc4.cxx
index b39b343..8b1848f 100644
--- a/sd/source/core/drawdoc4.cxx
+++ b/sd/source/core/drawdoc4.cxx
@@ -20,6 +20,7 @@
 #include <sal/config.h>
 
 #include <com/sun/star/style/XStyle.hpp>
+#include <com/sun/star/drawing/LineStyle.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <i18nlangtag/mslangid.hxx>
 #include <sfx2/docfile.hxx>
@@ -150,7 +151,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     XHatch    aNullHatch(aNullCol);
 
                     // Line attributes (Extended OutputDevice)
-    rISet.Put(XLineStyleItem(XLINE_SOLID));
+    rISet.Put(XLineStyleItem(drawing::LineStyle_SOLID));
     rISet.Put(XLineColorItem(OUString(), RGB_Color(COL_DEFAULT_SHAPE_STROKE)));
     rISet.Put(XLineWidthItem(0));
     rISet.Put(XLineDashItem(pPool,aNullDash));
@@ -261,7 +262,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_OBJWITHARROW );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_SOLID));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_SOLID));
     pISet->Put(XLineColorItem(OUString(), RGB_Color(COL_BLACK)));
     pISet->Put(XLineWidthItem(150));
 
@@ -307,7 +308,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pISet = &pSheet->GetItemSet();
 
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
 
     // Text
 
@@ -317,7 +318,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TEXT );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     // Text body
@@ -327,7 +328,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TEXTBODY );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     pISet->Put(SvxFontHeightItem(564, 100, EE_CHAR_FONTHEIGHT));        // 16 pt
@@ -339,7 +340,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TEXTBODY_JUSTIFY );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     pISet->Put(SvxAdjustItem(SVX_ADJUST_BLOCK, EE_PARA_JUST ));
@@ -351,7 +352,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TEXTBODY_INDENT );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     SvxLRSpaceItem aLRSpaceItem( EE_PARA_LRSPACE );
@@ -366,7 +367,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TITLE );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     pISet->Put(SvxFontHeightItem(1551, 100, EE_CHAR_FONTHEIGHT ));      // 44 pt
@@ -378,7 +379,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TITLE1 );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_SOLID));
     pISet->Put(XFillColorItem(OUString(), RGB_Color(COL_CYAN)));
 
@@ -428,7 +429,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_HEADLINE );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     pISet->Put(SvxFontHeightItem(846, 100, EE_CHAR_FONTHEIGHT ));        // 24 pt
@@ -443,7 +444,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_HEADLINE1 );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     pISet->Put(SvxWeightItem(WEIGHT_BOLD, EE_CHAR_WEIGHT ));
@@ -460,7 +461,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_HEADLINE2 );
     pISet = &pSheet->GetItemSet();
 
-    pISet->Put(XLineStyleItem(XLINE_NONE));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     pISet->Put(SvxPostureItem(ITALIC_NORMAL, EE_CHAR_ITALIC ));
@@ -487,7 +488,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pISet->Put(XLineStartWidthItem(200));
     pISet->Put(XLineEndItem(SVX_RESSTR(RID_SVXSTR_ARROW),::basegfx::B2DPolyPolygon(aArrow)));
     pISet->Put(XLineEndWidthItem(200));
-    pISet->Put(XLineStyleItem(XLINE_SOLID));
+    pISet->Put(XLineStyleItem(drawing::LineStyle_SOLID));
     pISet->Put(makeSdrMeasureShowUnitItem(true));
 
     // Generate presentation templates for default layout.
diff --git a/sd/source/core/stlpool.cxx b/sd/source/core/stlpool.cxx
index 5e4b30f..095054e 100644
--- a/sd/source/core/stlpool.cxx
+++ b/sd/source/core/stlpool.cxx
@@ -66,6 +66,8 @@
 #include <svl/itemset.hxx>
 #include "app.hrc"
 
+#include <com/sun/star/drawing/LineStyle.hpp>
+
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
@@ -252,7 +254,7 @@ void SdStyleSheetPool::CreateLayoutStyleSheets(const OUString& rLayoutName, bool
                 rSet.Put( SvxCharReliefItem(RELIEF_NONE, EE_CHAR_RELIEF) );
                 rSet.Put( SvxColorItem( Color(COL_AUTO), EE_CHAR_COLOR) );
                 rSet.Put( SvxBackgroundColorItem( Color (COL_AUTO), EE_CHAR_BKGCOLOR )  );
-                rSet.Put( XLineStyleItem(XLINE_NONE) );
+                rSet.Put( XLineStyleItem(com::sun::star::drawing::LineStyle_NONE) );
                 rSet.Put( XFillStyleItem(drawing::FillStyle_NONE) );
                 rSet.Put( SdrTextFitToSizeTypeItem(SDRTEXTFIT_AUTOFIT) );
                 rSet.Put( makeSdrTextAutoGrowHeightItem(false) );
@@ -346,7 +348,7 @@ void SdStyleSheetPool::CreateLayoutStyleSheets(const OUString& rLayoutName, bool
         pSheet->SetHelpId( aHelpFile, HID_PSEUDOSHEET_TITLE );
         pSheet->SetParent( OUString() );
         SfxItemSet& rTitleSet = pSheet->GetItemSet();
-        rTitleSet.Put(XLineStyleItem(XLINE_NONE));
+        rTitleSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
         rTitleSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
         rTitleSet.Put(aSvxFontItem);
         rTitleSet.Put(aSvxFontItemCJK);
@@ -392,7 +394,7 @@ void SdStyleSheetPool::CreateLayoutStyleSheets(const OUString& rLayoutName, bool
         pSheet->SetHelpId( aHelpFile, HID_PSEUDOSHEET_SUBTITLE );
         pSheet->SetParent( OUString() );
         SfxItemSet& rSubtitleSet = pSheet->GetItemSet();
-        rSubtitleSet.Put(XLineStyleItem(XLINE_NONE));
+        rSubtitleSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
         rSubtitleSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
         rSubtitleSet.Put(aSvxFontItem);
         rSubtitleSet.Put(aSvxFontItemCJK);
@@ -441,7 +443,7 @@ void SdStyleSheetPool::CreateLayoutStyleSheets(const OUString& rLayoutName, bool
         pSheet->SetHelpId( aHelpFile, HID_PSEUDOSHEET_NOTES );
         pSheet->SetParent( OUString() );
         SfxItemSet& rNotesSet = pSheet->GetItemSet();
-        rNotesSet.Put(XLineStyleItem(XLINE_NONE));
+        rNotesSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
         rNotesSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
         rNotesSet.Put(aSvxFontItem);
         rNotesSet.Put(aSvxFontItemCJK);
@@ -508,7 +510,7 @@ void SdStyleSheetPool::CreateLayoutStyleSheets(const OUString& rLayoutName, bool
         pSheet->SetHelpId( aHelpFile, HID_PSEUDOSHEET_BACKGROUND );
         pSheet->SetParent( OUString() );
         SfxItemSet& rBackgroundSet = pSheet->GetItemSet();
-        rBackgroundSet.Put(XLineStyleItem(XLINE_NONE));
+        rBackgroundSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
         rBackgroundSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
         // #i16874# enable kerning by default but only for new documents
         rBackgroundSet.Put( SvxAutoKernItem( true, EE_CHAR_PAIRKERNING ) );
diff --git a/sd/source/filter/ppt/pptin.cxx b/sd/source/filter/ppt/pptin.cxx
index 64c64ba..731fb65 100644
--- a/sd/source/filter/ppt/pptin.cxx
+++ b/sd/source/filter/ppt/pptin.cxx
@@ -86,6 +86,7 @@
 
 #include <com/sun/star/document/XDocumentProperties.hpp>
 #include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
+#include <com/sun/star/drawing/LineStyle.hpp>
 
 #include <comphelper/string.hxx>
 #include <oox/ole/olehelper.hxx>
@@ -2564,9 +2565,9 @@ SdrObject* ImplSdPPTImport::ProcessObj( SvStream& rSt, DffObjData& rObjData, voi
                                             const SfxItemSet& rObjItemSet = pObj->GetMergedItemSet();
 
                                             drawing::FillStyle eFillStyle = static_cast<const XFillStyleItem&>(rObjItemSet.Get(XATTR_FILLSTYLE)).GetValue();
-                                            XLineStyle eLineStyle = static_cast<const XLineStyleItem&>(rObjItemSet.Get(XATTR_LINESTYLE)).GetValue();
+                                            drawing::LineStyle eLineStyle = static_cast<const XLineStyleItem&>(rObjItemSet.Get(XATTR_LINESTYLE)).GetValue();
 
-                                            if ( ( eFillStyle == drawing::FillStyle_NONE ) && ( eLineStyle == XLINE_NONE ) )
+                                            if ( ( eFillStyle == drawing::FillStyle_NONE ) && ( eLineStyle == drawing::LineStyle_NONE ) )
                                                 bDontAnimateInvisibleShape = true;
                                         }
                                     }
diff --git a/sd/source/ui/animations/motionpathtag.cxx b/sd/source/ui/animations/motionpathtag.cxx
index 3c2951b..b3b2591 100644
--- a/sd/source/ui/animations/motionpathtag.cxx
+++ b/sd/source/ui/animations/motionpathtag.cxx
@@ -359,7 +359,7 @@ MotionPathTag::MotionPathTag( CustomAnimationPane& rPane, ::sd::View& rView, con
     XDash aDash( XDASH_RECT, 1, 80, 1, 80, 80);
     OUString aEmpty( "?" );
     mpPathObj->SetMergedItem( XLineDashItem( aEmpty, aDash ) );
-    mpPathObj->SetMergedItem( XLineStyleItem( XLINE_DASH ) );
+    mpPathObj->SetMergedItem( XLineStyleItem( drawing::LineStyle_DASH ) );
     mpPathObj->SetMergedItem( XLineColorItem(aEmpty, ::Color(COL_GRAY)) );
     mpPathObj->SetMergedItem( XFillStyleItem( drawing::FillStyle_NONE ) );
 
diff --git a/sd/source/ui/dlg/morphdlg.cxx b/sd/source/ui/dlg/morphdlg.cxx
index d00aa94..78fbcf4 100644
--- a/sd/source/ui/dlg/morphdlg.cxx
+++ b/sd/source/ui/dlg/morphdlg.cxx
@@ -29,6 +29,7 @@
 #include <svx/svdobj.hxx>
 #include <svl/itemset.hxx>
 #include <svl/itempool.hxx>
+#include <com/sun/star/drawing/LineStyle.hpp>
 
 using namespace com::sun::star;
 
@@ -51,12 +52,12 @@ MorphDlg::MorphDlg( vcl::Window* pParent, const SdrObject* pObj1, const SdrObjec
     aSet1.Put(pObj1->GetMergedItemSet());
     aSet2.Put(pObj2->GetMergedItemSet());
 
-    const XLineStyle    eLineStyle1 = static_cast<const XLineStyleItem&>( aSet1.Get( XATTR_LINESTYLE ) ).GetValue();
-    const XLineStyle    eLineStyle2 = static_cast<const XLineStyleItem&>( aSet2.Get( XATTR_LINESTYLE ) ).GetValue();
+    const drawing::LineStyle eLineStyle1 = static_cast<const XLineStyleItem&>( aSet1.Get( XATTR_LINESTYLE ) ).GetValue();
+    const drawing::LineStyle eLineStyle2 = static_cast<const XLineStyleItem&>( aSet2.Get( XATTR_LINESTYLE ) ).GetValue();
     const drawing::FillStyle eFillStyle1 = static_cast<const XFillStyleItem&>( aSet1.Get( XATTR_FILLSTYLE ) ).GetValue();
     const drawing::FillStyle eFillStyle2 = static_cast<const XFillStyleItem&>( aSet2.Get( XATTR_FILLSTYLE ) ).GetValue();
 
-    if ( ( ( eLineStyle1 == XLINE_NONE ) || ( eLineStyle2 == XLINE_NONE ) ) &&
+    if ( ( ( eLineStyle1 == drawing::LineStyle_NONE ) || ( eLineStyle2 == drawing::LineStyle_NONE ) ) &&
          ( ( eFillStyle1 != drawing::FillStyle_SOLID ) || ( eFillStyle2 != drawing::FillStyle_SOLID ) ) )
     {
         m_pCbxAttributes->Disable();
diff --git a/sd/source/ui/func/fucon3d.cxx b/sd/source/ui/func/fucon3d.cxx
index d8685cb..b266637 100644
--- a/sd/source/ui/func/fucon3d.cxx
+++ b/sd/source/ui/func/fucon3d.cxx
@@ -48,6 +48,8 @@
 #include <svx/polysc3d.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 
+using namespace com::sun::star;
+
 namespace sd {
 
 TYPEINIT1( FuConstruct3dObject, FuConstruct );
@@ -326,7 +328,7 @@ bool FuConstruct3dObject::MouseButtonDown(const MouseEvent& rMEvt)
             SetStyleSheet(aAttr, pObj);
 
             // extract LineStyle
-            aAttr.Put(XLineStyleItem (XLINE_NONE));
+            aAttr.Put(XLineStyleItem (drawing::LineStyle_NONE));
 
             pObj->SetMergedItemSet(aAttr);
         }
@@ -415,7 +417,7 @@ SdrObject* FuConstruct3dObject::CreateDefaultObject(const sal_uInt16 nID, const
 
     SfxItemSet aAttr(mpDoc->GetPool());
     SetStyleSheet(aAttr, p3DObj);
-    aAttr.Put(XLineStyleItem (XLINE_NONE));
+    aAttr.Put(XLineStyleItem (drawing::LineStyle_NONE));
     p3DObj->SetMergedItemSet(aAttr);
 
     // make object interactive at once
diff --git a/sd/source/ui/func/fuexpand.cxx b/sd/source/ui/func/fuexpand.cxx
index 2d5e484..6eebb5b 100644
--- a/sd/source/ui/func/fuexpand.cxx
+++ b/sd/source/ui/func/fuexpand.cxx
@@ -239,7 +239,7 @@ void FuExpandPage::DoExecute( SfxRequest& )
 
                         // remove hard attributes (Flag to sal_True)
                         SfxItemSet aAttr(mpDoc->GetPool());
-                        aAttr.Put(XLineStyleItem(XLINE_NONE));
+                        aAttr.Put(XLineStyleItem(drawing::LineStyle_NONE));
                         aAttr.Put(XFillStyleItem(drawing::FillStyle_NONE));
                         pOutlineObj->SetMergedItemSet(aAttr);
                     }
diff --git a/sd/source/ui/func/fumorph.cxx b/sd/source/ui/func/fumorph.cxx
index 475c63a..d2fe87d 100644
--- a/sd/source/ui/func/fumorph.cxx
+++ b/sd/source/ui/func/fumorph.cxx
@@ -44,6 +44,7 @@
 
 #include <basegfx/color/bcolor.hxx>
 #include <boost/scoped_ptr.hpp>
+#include <com/sun/star/drawing/LineStyle.hpp>
 
 using namespace com::sun::star;
 
@@ -354,14 +355,14 @@ void FuMorph::ImpInsertPolygons(
     aSet1.Put(pObj1->GetMergedItemSet());
     aSet2.Put(pObj2->GetMergedItemSet());
 
-    const XLineStyle eLineStyle1 = ITEMVALUE( aSet1, XATTR_LINESTYLE, XLineStyleItem );
-    const XLineStyle eLineStyle2 = ITEMVALUE( aSet2, XATTR_LINESTYLE, XLineStyleItem );
+    const drawing::LineStyle eLineStyle1 = ITEMVALUE( aSet1, XATTR_LINESTYLE, XLineStyleItem );
+    const drawing::LineStyle eLineStyle2 = ITEMVALUE( aSet2, XATTR_LINESTYLE, XLineStyleItem );
     const drawing::FillStyle eFillStyle1 = ITEMVALUE( aSet1, XATTR_FILLSTYLE, XFillStyleItem );
     const drawing::FillStyle eFillStyle2 = ITEMVALUE( aSet2, XATTR_FILLSTYLE, XFillStyleItem );
 
     if ( bAttributeFade )
     {
-        if ( ( eLineStyle1 != XLINE_NONE ) && ( eLineStyle2 != XLINE_NONE ) )
+        if ( ( eLineStyle1 != drawing::LineStyle_NONE ) && ( eLineStyle2 != drawing::LineStyle_NONE ) )
         {
             bLineWidth = bLineColor = true;
 
@@ -373,7 +374,7 @@ void FuMorph::ImpInsertPolygons(
             nStartLineWidth = ITEMVALUE( aSet1, XATTR_LINEWIDTH, XLineWidthItem );
             nEndLineWidth = ITEMVALUE( aSet2, XATTR_LINEWIDTH, XLineWidthItem );
         }
-        else if ( ( eLineStyle1 == XLINE_NONE ) && ( eLineStyle2 == XLINE_NONE ) )
+        else if ( ( eLineStyle1 == drawing::LineStyle_NONE ) && ( eLineStyle2 == drawing::LineStyle_NONE ) )
             bIgnoreLine = true;
 
         if ( ( eFillStyle1 == drawing::FillStyle_SOLID ) && ( eFillStyle2 == drawing::FillStyle_SOLID ) )
@@ -398,7 +399,7 @@ void FuMorph::ImpInsertPolygons(
         const double    fDelta = nEndLineWidth - nStartLineWidth;
         double          fFactor = fStep;
 
-        aSet.Put( XLineStyleItem( XLINE_SOLID ) );
+        aSet.Put( XLineStyleItem( drawing::LineStyle_SOLID ) );
         aSet.Put( XFillStyleItem( drawing::FillStyle_SOLID ) );
 
         for ( size_t i = 0; i < nCount; i++, fFactor += fStep )
@@ -413,7 +414,7 @@ void FuMorph::ImpInsertPolygons(
                 aSet.Put( XLineColorItem( aEmptyStr, Color(aLineColor)));
             }
             else if ( bIgnoreLine )
-                aSet.Put( XLineStyleItem( XLINE_NONE ) );
+                aSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
 
             // fill color
             if ( bFillColor )
diff --git a/sd/source/ui/func/fusumry.cxx b/sd/source/ui/func/fusumry.cxx
index 3ec9524..f81950c 100644
--- a/sd/source/ui/func/fusumry.cxx
+++ b/sd/source/ui/func/fusumry.cxx
@@ -210,7 +210,7 @@ void FuSummaryPage::DoExecute( SfxRequest& )
 
     // remove hard attributes (Flag to sal_True)
     SfxItemSet aAttr(mpDoc->GetPool());
-    aAttr.Put(XLineStyleItem(XLINE_NONE));
+    aAttr.Put(XLineStyleItem(drawing::LineStyle_NONE));
     aAttr.Put(XFillStyleItem(drawing::FillStyle_NONE));
     pTextObj->SetMergedItemSet(aAttr);
 
diff --git a/sd/source/ui/view/DocumentRenderer.cxx b/sd/source/ui/view/DocumentRenderer.cxx
index fe024fc..4cf3d54 100644
--- a/sd/source/ui/view/DocumentRenderer.cxx
+++ b/sd/source/ui/view/DocumentRenderer.cxx
@@ -1002,7 +1002,7 @@ namespace {
                         if (nSkip > 0)
                             --nSkip;
                         else
-                            pPathObj->SetMergedItem(XLineStyleItem(XLINE_NONE));
+                            pPathObj->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
                     }
                 }
             }
@@ -1049,7 +1049,7 @@ namespace {
                 {
                     SdrPathObj* pPathObj = dynamic_cast<SdrPathObj*>(aShapeIter.Next());
                     if (pPathObj != NULL)
-                        pPathObj->SetMergedItem(XLineStyleItem(XLINE_SOLID));
+                        pPathObj->SetMergedItem(XLineStyleItem(drawing::LineStyle_SOLID));
                 }
             }
 
@@ -1567,7 +1567,7 @@ private:
                 }
 
                 SdrPathObj* pPathObj = new SdrPathObj(OBJ_PATHLINE, aPathPoly );
-                pPathObj->SetMergedItem(XLineStyleItem(XLINE_SOLID));
+                pPathObj->SetMergedItem(XLineStyleItem(drawing::LineStyle_SOLID));
                 pPathObj->SetMergedItem(XLineColorItem(OUString(), Color(COL_BLACK)));
 
                 pHandout->NbcInsertObject( pPathObj );
diff --git a/sd/source/ui/view/drviews9.cxx b/sd/source/ui/view/drviews9.cxx
index 0e67b96..f7308c0 100644
--- a/sd/source/ui/view/drviews9.cxx
+++ b/sd/source/ui/view/drviews9.cxx
@@ -59,6 +59,7 @@
 
 #include <svx/galleryitem.hxx>
 #include <com/sun/star/gallery/GalleryItemType.hpp>
+#include <com/sun/star/drawing/LineStyle.hpp>
 #include <boost/scoped_ptr.hpp>
 
 using namespace com::sun::star;
@@ -236,10 +237,10 @@ void DrawViewShell::AttrExec (SfxRequest &rReq)
                 if (pArgs->Count () == 1)
                 {
                     SFX_REQUEST_ARG (rReq, pLineStyle, SfxUInt32Item, ID_VAL_STYLE, false);
-                    if (CHECK_RANGE (XLINE_NONE, (sal_Int32)pLineStyle->GetValue (), XLINE_DASH))
+                    if (CHECK_RANGE (drawing::LineStyle_NONE, (sal_Int32)pLineStyle->GetValue (), drawing::LineStyle_DASH))
                     {
                         pAttr->ClearItem (XATTR_LINESTYLE);
-                        pAttr->Put (XLineStyleItem ((XLineStyle) pLineStyle->GetValue ()), XATTR_LINESTYLE);
+                        pAttr->Put (XLineStyleItem ((drawing::LineStyle) pLineStyle->GetValue ()), XATTR_LINESTYLE);
                         rBindings.Invalidate (SID_ATTR_LINE_STYLE);
                     }
 #if HAVE_FEATURE_SCRIPTING
@@ -465,7 +466,7 @@ void DrawViewShell::AttrExec (SfxRequest &rReq)
                             pDashList->Insert (pEntry);
 
                         pAttr->Put (XLineDashItem (pName->GetValue (), aNewDash), XATTR_LINEDASH);
-                        pAttr->Put (XLineStyleItem (XLINE_DASH), XATTR_LINESTYLE);
+                        pAttr->Put (XLineStyleItem (drawing::LineStyle_DASH), XATTR_LINESTYLE);
                         rBindings.Invalidate (SID_ATTR_LINE_DASH);
                         rBindings.Invalidate (SID_ATTR_FILL_STYLE);
                     }
diff --git a/svx/source/customshapes/EnhancedCustomShape2d.cxx b/svx/source/customshapes/EnhancedCustomShape2d.cxx
index 1e0e818..225ec26 100644
--- a/svx/source/customshapes/EnhancedCustomShape2d.cxx
+++ b/svx/source/customshapes/EnhancedCustomShape2d.cxx
@@ -695,7 +695,7 @@ EnhancedCustomShape2d::EnhancedCustomShape2d( SdrObject* pAObj ) :
     nColorData          ( 0 ),
     bTextFlow           ( false ),
     bFilled             ( static_cast<const XFillStyleItem&>(pAObj->GetMergedItem( XATTR_FILLSTYLE )).GetValue() != drawing::FillStyle_NONE ),
-    bStroked            ( static_cast<const XLineStyleItem&>(pAObj->GetMergedItem( XATTR_LINESTYLE )).GetValue() != XLINE_NONE ),
+    bStroked            ( static_cast<const XLineStyleItem&>(pAObj->GetMergedItem( XATTR_LINESTYLE )).GetValue() != drawing::LineStyle_NONE ),
     bFlipH              ( false ),
     bFlipV              ( false )
 {
@@ -1942,7 +1942,7 @@ void EnhancedCustomShape2d::CreateSubPath( sal_uInt16& rSrcPt, sal_uInt16& rSegm
                 SdrPathObj* pFill = new SdrPathObj(OBJ_POLY, aClosedPolyPolygon, dBrightness);
                 SfxItemSet aTempSet(*this);
                 aTempSet.Put(makeSdrShadowItem(false));
-                aTempSet.Put(XLineStyleItem(XLINE_NONE));
+                aTempSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
                 pFill->SetMergedItemSet(aTempSet);
                 rObjectList.push_back(pFill);
             }
@@ -1985,7 +1985,7 @@ void EnhancedCustomShape2d::CreateSubPath( sal_uInt16& rSrcPt, sal_uInt16& rSegm
 
             if(bNoStroke)
             {
-                aTempSet.Put(XLineStyleItem(XLINE_NONE));
+                aTempSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
             }
 
             if(pObj)
@@ -2200,11 +2200,11 @@ SdrObject* EnhancedCustomShape2d::CreatePathObj( bool bLineGeometryNeededOnly )
             for(size_t i = 0; i < vObjectList.size(); ++i)
             {
                 SdrPathObj* pObj(vObjectList[i]);
-                const XLineStyle eLineStyle =static_cast<const XLineStyleItem&>(pObj->GetMergedItem(XATTR_LINESTYLE)).GetValue();
+                const drawing::LineStyle eLineStyle =static_cast<const XLineStyleItem&>(pObj->GetMergedItem(XATTR_LINESTYLE)).GetValue();
                 const drawing::FillStyle eFillStyle = static_cast<const XFillStyleItem&>(pObj->GetMergedItem(XATTR_FILLSTYLE)).GetValue();
 
                 //SJ: #i40600# if bLineGeometryNeededOnly is set linystyle does not matter
-                if( !bLineGeometryNeededOnly && ( XLINE_NONE == eLineStyle ) && ( drawing::FillStyle_NONE == eFillStyle ) )
+                if( !bLineGeometryNeededOnly && ( drawing::LineStyle_NONE == eLineStyle ) && ( drawing::FillStyle_NONE == eFillStyle ) )
                     delete pObj;
                 else
                     vTempList.push_back(pObj);
diff --git a/svx/source/customshapes/EnhancedCustomShape3d.cxx b/svx/source/customshapes/EnhancedCustomShape3d.cxx
index 60dcb86..be54d21 100644
--- a/svx/source/customshapes/EnhancedCustomShape3d.cxx
+++ b/svx/source/customshapes/EnhancedCustomShape3d.cxx
@@ -342,13 +342,13 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
 
         if ( eShadeMode == drawing::ShadeMode_DRAFT )
         {
-            aSet.Put( XLineStyleItem( XLINE_SOLID ) );
+            aSet.Put( XLineStyleItem( drawing::LineStyle_SOLID ) );
             aSet.Put( XFillStyleItem ( drawing::FillStyle_NONE ) );
             aSet.Put( makeSvx3DDoubleSidedItem( true ) );
         }
         else
         {
-            aSet.Put( XLineStyleItem( XLINE_NONE ) );
+            aSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
             if ( eFillStyle == drawing::FillStyle_NONE )
                 aSet.Put( XFillStyleItem( drawing::FillStyle_SOLID ) );
             else if ( ( eFillStyle == drawing::FillStyle_BITMAP ) || ( eFillStyle == drawing::FillStyle_GRADIENT ) || bUseExtrusionColor )
@@ -376,7 +376,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
         {
             const SdrObject* pNext = aIter.Next();
             bool bIsPlaceholderObject = (static_cast<const XFillStyleItem&>(pNext->GetMergedItem( XATTR_FILLSTYLE )).GetValue() == drawing::FillStyle_NONE )
-                                        && (static_cast<const XLineStyleItem&>(pNext->GetMergedItem( XATTR_LINESTYLE )).GetValue() == XLINE_NONE );
+                                        && (static_cast<const XLineStyleItem&>(pNext->GetMergedItem( XATTR_LINESTYLE )).GetValue() == drawing::LineStyle_NONE );
             basegfx::B2DPolyPolygon aPolyPoly;
             SfxItemSet aLocalSet(aSet);
             drawing::FillStyle aLocalFillStyle(eFillStyle);
@@ -430,7 +430,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
                             if(eShadeMode == drawing::ShadeMode_DRAFT)
                             {
                                 // for draft, create wireframe with fixed line width
-                                aLocalSet.Put(XLineStyleItem(XLINE_SOLID));
+                                aLocalSet.Put(XLineStyleItem(drawing::LineStyle_SOLID));
                                 aLocalSet.Put(XLineWidthItem(40));
                                 aLocalFillStyle = drawing::FillStyle_NONE;
                             }
@@ -438,7 +438,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
                             {
                                 // switch from line to fill, copy line attr to fill attr (color, transparence)
                                 aLocalSet.Put(XLineWidthItem(0));
-                                aLocalSet.Put(XLineStyleItem(XLINE_NONE));
+                                aLocalSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
                                 aLocalSet.Put(XFillColorItem(OUString(), static_cast<const XLineColorItem&>(aLocalSet.Get(XATTR_LINECOLOR)).GetColorValue()));
                                 aLocalSet.Put(XFillStyleItem(drawing::FillStyle_SOLID));
                                 aLocalSet.Put(XFillTransparenceItem(static_cast<const XLineTransparenceItem&>(aLocalSet.Get(XATTR_LINETRANSPARENCE)).GetValue()));
@@ -449,7 +449,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
                         {
                             // correct item properties to hairlines
                             aLocalSet.Put(XLineWidthItem(0));
-                            aLocalSet.Put(XLineStyleItem(XLINE_SOLID));
+                            aLocalSet.Put(XLineStyleItem(drawing::LineStyle_SOLID));
                         }
                     }
 
diff --git a/svx/source/customshapes/EnhancedCustomShapeEngine.cxx b/svx/source/customshapes/EnhancedCustomShapeEngine.cxx
index 2d26c30..2beb70f 100644
--- a/svx/source/customshapes/EnhancedCustomShapeEngine.cxx
+++ b/svx/source/customshapes/EnhancedCustomShapeEngine.cxx
@@ -204,7 +204,7 @@ SdrObject* EnhancedCustomShapeEngine::ImplForceGroupWithText( const SdrObjCustom
             SfxItemSet aTargetItemSet( pCustoObj->GetMergedItemSet() );
 
             // clear fill and line style
-            aTargetItemSet.Put(XLineStyleItem(XLINE_NONE));
+            aTargetItemSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
             aTargetItemSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
 
             // get the text bounds and set at text object
diff --git a/svx/source/dialog/dlgctl3d.cxx b/svx/source/dialog/dlgctl3d.cxx
index 911b607..4711b30 100644
--- a/svx/source/dialog/dlgctl3d.cxx
+++ b/svx/source/dialog/dlgctl3d.cxx
@@ -137,7 +137,7 @@ void Svx3DPreviewControl::Construct()
         XATTR_LINESTYLE, XATTR_LINESTYLE,
         XATTR_FILL_FIRST, XATTR_FILLBITMAP,
         0, 0 );
-    aSet.Put( XLineStyleItem( XLINE_NONE ) );
+    aSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
     aSet.Put( XFillStyleItem( drawing::FillStyle_SOLID ) );
     aSet.Put( XFillColorItem( "", Color( COL_WHITE ) ) );
 
@@ -303,7 +303,7 @@ void Svx3DLightControl::Construct2()
             basegfx::B3DVector(2.0 * fMaxExpansion, 2.0 * fMaxExpansion, 2.0 * fMaxExpansion));
         mpScene->Insert3DObj( mpExpansionObject );
         SfxItemSet aSet(mpModel->GetItemPool());
-        aSet.Put( XLineStyleItem( XLINE_NONE ) );
+        aSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
         aSet.Put( XFillStyleItem( drawing::FillStyle_NONE ) );
         mpExpansionObject->SetMergedItemSet(aSet);
     }
@@ -343,7 +343,7 @@ void Svx3DLightControl::Construct2()
 
         // initially invisible
         SfxItemSet aSet(mpModel->GetItemPool());
-        aSet.Put( XLineStyleItem( XLINE_NONE ) );
+        aSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
         aSet.Put( XFillStyleItem( drawing::FillStyle_NONE ) );
 
         mpLampBottomObject->SetMergedItemSet(aSet);
@@ -409,7 +409,7 @@ void Svx3DLightControl::ConstructLightObjects()
             pNewLight->SetTransform(aTransform);
 
             SfxItemSet aSet(mpModel->GetItemPool());
-            aSet.Put( XLineStyleItem( XLINE_NONE ) );
+            aSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
             aSet.Put( XFillStyleItem( drawing::FillStyle_SOLID ) );
             aSet.Put( XFillColorItem(OUString(), GetLightColor(a)));
             pNewLight->SetMergedItemSet(aSet);
@@ -425,7 +425,7 @@ void Svx3DLightControl::AdaptToSelectedLight()
     {
         // make mpLampBottomObject/mpLampShaftObject invisible
         SfxItemSet aSet(mpModel->GetItemPool());
-        aSet.Put( XLineStyleItem( XLINE_NONE ) );
+        aSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
         aSet.Put( XFillStyleItem( drawing::FillStyle_NONE ) );
         mpLampBottomObject->SetMergedItemSet(aSet);
         mpLampShaftObject->SetMergedItemSet(aSet);
@@ -437,7 +437,7 @@ void Svx3DLightControl::AdaptToSelectedLight()
 
         // make mpLampBottomObject/mpLampShaftObject visible (yellow hairline)
         SfxItemSet aSet(mpModel->GetItemPool());
-        aSet.Put( XLineStyleItem( XLINE_SOLID ) );
+        aSet.Put( XLineStyleItem( drawing::LineStyle_SOLID ) );
         aSet.Put( XLineColorItem(OUString(), COL_YELLOW));
         aSet.Put( XLineWidthItem(0));
         aSet.Put( XFillStyleItem( drawing::FillStyle_NONE ) );
diff --git a/svx/source/dialog/dlgctrl.cxx b/svx/source/dialog/dlgctrl.cxx
index 1ff3a68..f4d7d8b 100644
--- a/svx/source/dialog/dlgctrl.cxx
+++ b/svx/source/dialog/dlgctrl.cxx
@@ -51,6 +51,7 @@
 #define OUTPUT_DRAWMODE_COLOR       (DRAWMODE_DEFAULT)
 #define OUTPUT_DRAWMODE_CONTRAST    (DRAWMODE_SETTINGSLINE | DRAWMODE_SETTINGSFILL | DRAWMODE_SETTINGSTEXT | DRAWMODE_SETTINGSGRADIENT)
 
+using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::accessibility;
@@ -2107,7 +2108,7 @@ SvxXRectPreview::~SvxXRectPreview()
 void SvxXRectPreview::SetAttributes(const SfxItemSet& rItemSet)
 {
     mpRectangleObject->SetMergedItemSet(rItemSet, true);
-    mpRectangleObject->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    mpRectangleObject->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
 }
 
 void SvxXRectPreview::Paint( const Rectangle& )
@@ -2163,13 +2164,13 @@ SvxXShadowPreview::~SvxXShadowPreview()
 void SvxXShadowPreview::SetRectangleAttributes(const SfxItemSet& rItemSet)
 {
     mpRectangleObject->SetMergedItemSet(rItemSet, true);
-    mpRectangleObject->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    mpRectangleObject->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
 }
 
 void SvxXShadowPreview::SetShadowAttributes(const SfxItemSet& rItemSet)
 {
     mpRectangleShadow->SetMergedItemSet(rItemSet, true);
-    mpRectangleShadow->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    mpRectangleShadow->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
 }
 
 void SvxXShadowPreview::SetShadowPosition(const Point& rPos)
diff --git a/svx/source/engine3d/extrud3d.cxx b/svx/source/engine3d/extrud3d.cxx
index 3769117..594fd5c 100644
--- a/svx/source/engine3d/extrud3d.cxx
+++ b/svx/source/engine3d/extrud3d.cxx
@@ -203,7 +203,7 @@ SdrAttrObj* E3dExtrudeObj::GetBreakObj()
         if(pPathObj)
         {
             SfxItemSet aSet(GetObjectItemSet());
-            aSet.Put(XLineStyleItem(XLINE_SOLID));
+            aSet.Put(XLineStyleItem(com::sun::star::drawing::LineStyle_SOLID));
             pPathObj->SetMergedItemSet(aSet);
         }
 
diff --git a/svx/source/engine3d/lathe3d.cxx b/svx/source/engine3d/lathe3d.cxx
index 1950a7e..bb53605 100644
--- a/svx/source/engine3d/lathe3d.cxx
+++ b/svx/source/engine3d/lathe3d.cxx
@@ -188,7 +188,7 @@ SdrAttrObj* E3dLatheObj::GetBreakObj()
         SfxItemSet aSet(GetObjectItemSet());
 
         // Enable lines to guarantee that the object becomes visible
-        aSet.Put(XLineStyleItem(XLINE_SOLID));
+        aSet.Put(XLineStyleItem(com::sun::star::drawing::LineStyle_SOLID));
 
         pPathObj->SetMergedItemSet(aSet);
     }
diff --git a/svx/source/engine3d/view3d.cxx b/svx/source/engine3d/view3d.cxx
index 7107f62..e1e47c7 100644
--- a/svx/source/engine3d/view3d.cxx
+++ b/svx/source/engine3d/view3d.cxx
@@ -684,17 +684,17 @@ void E3dView::ImpChangeSomeAttributesFor3DConversion2(SdrObject* pObj)
     {
         const SfxItemSet& rSet = pObj->GetMergedItemSet();
         sal_Int32 nLineWidth = static_cast<const XLineWidthItem&>(rSet.Get(XATTR_LINEWIDTH)).GetValue();
-        XLineStyle eLineStyle = (XLineStyle)static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE)).GetValue();
+        drawing::LineStyle eLineStyle = (drawing::LineStyle)static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE)).GetValue();
         drawing::FillStyle eFillStyle = ITEMVALUE(rSet, XATTR_FILLSTYLE, XFillStyleItem);
 
         if(static_cast<SdrPathObj*>(pObj)->IsClosed()
-            && eLineStyle == XLINE_SOLID
+            && eLineStyle == drawing::LineStyle_SOLID
             && !nLineWidth
             && eFillStyle != drawing::FillStyle_NONE)
         {
             if(pObj->GetPage() && GetModel()->IsUndoEnabled() )
                 AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoAttrObject(*pObj, false, false));
-            pObj->SetMergedItem(XLineStyleItem(XLINE_NONE));
+            pObj->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
             pObj->SetMergedItem(XLineWidthItem(0L));
         }
     }
@@ -719,7 +719,7 @@ void E3dView::ImpCreateSingle3DObjectFlat(E3dScene* pScene, SdrObject* pObj, boo
         drawing::FillStyle eFillStyle = ITEMVALUE(aSet, XATTR_FILLSTYLE, XFillStyleItem);
 
         // line style turned off
-        aSet.Put(XLineStyleItem(XLINE_NONE));
+        aSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
 
         //Determining if FILL_Attribut is set.
         if(!pPath->IsClosed() || eFillStyle == drawing::FillStyle_NONE)
diff --git a/svx/source/engine3d/view3d1.cxx b/svx/source/engine3d/view3d1.cxx
index 6a392d8..66d667b 100644
--- a/svx/source/engine3d/view3d1.cxx
+++ b/svx/source/engine3d/view3d1.cxx
@@ -40,6 +40,7 @@
 #include <svx/xflclit.hxx>
 #include <svx/svdogrp.hxx>
 #include <svx/e3dsceneupdater.hxx>
+#include <com/sun/star/drawing/LineStyle.hpp>
 
 void E3dView::ConvertMarkedToPolyObj(bool bLineToArea)
 {
@@ -139,7 +140,7 @@ SfxItemSet E3dView::Get3DAttributes(E3dScene* pInScene, bool /*bOnly3DAttr*/) co
         aSet.Put(aDefaultSet);
 
         // ... but no lines for 3D
-        aSet.Put(XLineStyleItem (XLINE_NONE));
+        aSet.Put(XLineStyleItem (com::sun::star::drawing::LineStyle_NONE));
 
         // new defaults for distance and focal length
         aSet.Put(makeSvx3DDistanceItem(100));
diff --git a/svx/source/sdr/attribute/sdrformtextattribute.cxx b/svx/source/sdr/attribute/sdrformtextattribute.cxx
index 319c893..2210191 100644
--- a/svx/source/sdr/attribute/sdrformtextattribute.cxx
+++ b/svx/source/sdr/attribute/sdrformtextattribute.cxx
@@ -44,6 +44,7 @@
 #include <drawinglayer/attribute/strokeattribute.hxx>
 #include <sdr/attribute/sdrformtextoutlineattribute.hxx>
 #include <com/sun/star/drawing/LineCap.hpp>
+#include <com/sun/star/drawing/LineStyle.hpp>
 
 
 // helper to get line, stroke and transparence attributes from SfxItemSet
@@ -121,11 +122,11 @@ namespace
 
     drawinglayer::attribute::StrokeAttribute impGetStrokeAttribute(const SfxItemSet& rSet)
     {
-        const XLineStyle eLineStyle = (static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE))).GetValue();
+        const com::sun::star::drawing::LineStyle eLineStyle = (static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE))).GetValue();
         double fFullDotDashLen(0.0);
         ::std::vector< double > aDotDashArray;
 
-        if(XLINE_DASH == eLineStyle)
+        if(com::sun::star::drawing::LineStyle_DASH == eLineStyle)
         {
             const XDash& rDash = (static_cast<const XLineDashItem&>(rSet.Get(XATTR_LINEDASH))).GetDashValue();
 
diff --git a/svx/source/sdr/contact/viewcontactofsdrcaptionobj.cxx b/svx/source/sdr/contact/viewcontactofsdrcaptionobj.cxx
index 0882508..629b8aa 100644
--- a/svx/source/sdr/contact/viewcontactofsdrcaptionobj.cxx
+++ b/svx/source/sdr/contact/viewcontactofsdrcaptionobj.cxx
@@ -116,7 +116,7 @@ namespace sdr
                 // Create own ItemSet and modify as needed
                 // Always hide lines for special calc shadow
                 SfxItemSet aSet(rItemSet);
-                aSet.Put(XLineStyleItem(XLINE_NONE));
+                aSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
 
                 if(drawing::FillStyle_HATCH == eShadowStyle)
                 {
diff --git a/svx/source/sdr/primitive2d/sdrattributecreator.cxx b/svx/source/sdr/primitive2d/sdrattributecreator.cxx
index 71b6ac7..35fe335 100644
--- a/svx/source/sdr/primitive2d/sdrattributecreator.cxx
+++ b/svx/source/sdr/primitive2d/sdrattributecreator.cxx
@@ -218,9 +218,9 @@ namespace drawinglayer
     {
         attribute::SdrLineAttribute createNewSdrLineAttribute(const SfxItemSet& rSet)
         {
-            const XLineStyle eStyle(static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE)).GetValue());
+            const com::sun::star::drawing::LineStyle eStyle(static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE)).GetValue());
 
-            if(XLINE_NONE != eStyle)
+            if(drawing::LineStyle_NONE != eStyle)
             {
                 sal_uInt16 nTransparence(static_cast<const XLineTransparenceItem&>(rSet.Get(XATTR_LINETRANSPARENCE)).GetValue());
 
@@ -238,7 +238,7 @@ namespace drawinglayer
                     ::std::vector< double > aDotDashArray;
                     double fFullDotDashLen(0.0);
 
-                    if(XLINE_DASH == eStyle)
+                    if(drawing::LineStyle_DASH == eStyle)
                     {
                         const XDash& rDash = static_cast<const XLineDashItem&>(rSet.Get(XATTR_LINEDASH)).GetDashValue();
 
diff --git a/svx/source/sdr/properties/measureproperties.cxx b/svx/source/sdr/properties/measureproperties.cxx
index cf700c0..13bf605 100644
--- a/svx/source/sdr/properties/measureproperties.cxx
+++ b/svx/source/sdr/properties/measureproperties.cxx
@@ -32,7 +32,6 @@
 #include <basegfx/polygon/b2dpolygon.hxx>
 
 
-
 namespace sdr
 {
     namespace properties
@@ -121,7 +120,7 @@ namespace sdr
             mpItemSet->Put(XLineStartWidthItem(200));
             mpItemSet->Put(XLineEndItem(OUString(), basegfx::B2DPolyPolygon(aNewPolygon)));
             mpItemSet->Put(XLineEndWidthItem(200));
-            mpItemSet->Put(XLineStyleItem(XLINE_SOLID));
+            mpItemSet->Put(XLineStyleItem(com::sun::star::drawing::LineStyle_SOLID));
         }
     } // end of namespace properties
 } // end of namespace sdr
diff --git a/svx/source/sdr/properties/textproperties.cxx b/svx/source/sdr/properties/textproperties.cxx
index b80833f..a62fb35 100644
--- a/svx/source/sdr/properties/textproperties.cxx
+++ b/svx/source/sdr/properties/textproperties.cxx
@@ -207,7 +207,7 @@ namespace sdr
 
                 if(nDifference)
                 {
-                    const bool bLineVisible(XLINE_NONE != static_cast<const XLineStyleItem&>(GetItem(XATTR_LINESTYLE)).GetValue());
+                    const bool bLineVisible(drawing::LineStyle_NONE != static_cast<const XLineStyleItem&>(GetItem(XATTR_LINESTYLE)).GetValue());
 
                     if(bLineVisible)
                     {
@@ -376,7 +376,7 @@ namespace sdr
 
             if(bTextFrame)
             {
-                mpItemSet->Put(XLineStyleItem(XLINE_NONE));
+                mpItemSet->Put(XLineStyleItem(drawing::LineStyle_NONE));
                 mpItemSet->Put(XFillColorItem(OUString(), Color(COL_WHITE)));
                 mpItemSet->Put(XFillStyleItem(drawing::FillStyle_NONE));
             }
diff --git a/svx/source/sidebar/line/LinePropertyPanel.cxx b/svx/source/sidebar/line/LinePropertyPanel.cxx
index c5f9719..1442c40 100644
--- a/svx/source/sidebar/line/LinePropertyPanel.cxx
+++ b/svx/source/sidebar/line/LinePropertyPanel.cxx
@@ -631,22 +631,22 @@ IMPL_LINK_NOARG(LinePropertyPanel, ChangeLineStyleHdl)
     {
         if(0 == nPos)
         {
-            // XLINE_NONE
-            const XLineStyleItem aItem(XLINE_NONE);
+            // drawing::LineStyle_NONE
+            const XLineStyleItem aItem(drawing::LineStyle_NONE);
 
             GetBindings()->GetDispatcher()->Execute(SID_ATTR_LINE_STYLE, SfxCallMode::RECORD, &aItem, 0L);
         }
         else if(1 == nPos)
         {
-            // XLINE_SOLID
-            const XLineStyleItem aItem(XLINE_SOLID);
+            // drawing::LineStyle_SOLID
+            const XLineStyleItem aItem(drawing::LineStyle_SOLID);
 
             GetBindings()->GetDispatcher()->Execute(SID_ATTR_LINE_STYLE, SfxCallMode::RECORD, &aItem, 0L);
         }
         else if (mxLineStyleList.is() && mxLineStyleList->Count() > (long)(nPos - 2))
         {
-            // XLINE_DASH
-            const XLineStyleItem aItemA(XLINE_DASH);
+            // drawing::LineStyle_DASH
+            const XLineStyleItem aItemA(drawing::LineStyle_DASH);
             const XDashEntry* pDashEntry = mxLineStyleList->GetDash(nPos - 2);
             OSL_ENSURE(pDashEntry, "OOps, got empty XDash from XDashList (!)");
             const XLineDashItem aItemB(
@@ -926,14 +926,14 @@ void LinePropertyPanel::SelectLineStyle()
         return;
     }
 
-    const XLineStyle eXLS(mpStyleItem ? (XLineStyle)mpStyleItem->GetValue() : XLINE_NONE);
+    const drawing::LineStyle eXLS(mpStyleItem ? (drawing::LineStyle)mpStyleItem->GetValue() : drawing::LineStyle_NONE);
     bool bSelected(false);
 
     switch(eXLS)
     {
-        case XLINE_NONE:
+        case drawing::LineStyle_NONE:
             break;
-        case XLINE_SOLID:
+        case drawing::LineStyle_SOLID:
             mpLBStyle->SelectEntryPos(1);
             bSelected = true;
             break;
diff --git a/svx/source/svdraw/svdcrtv.cxx b/svx/source/svdraw/svdcrtv.cxx
index 2f3022f..b86a31a 100644
--- a/svx/source/svdraw/svdcrtv.cxx
+++ b/svx/source/svdraw/svdcrtv.cxx
@@ -469,7 +469,7 @@ bool SdrCreateView::ImpBegCreateObj(sal_uInt32 nInvent, sal_uInt16 nIdent, const
                     aSet.Put(XFillColorItem(OUString(),Color(COL_WHITE))); // in case someone turns on Solid
                     aSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
                     aSet.Put(XLineColorItem(OUString(),Color(COL_BLACK))); // in case someone turns on Solid
-                    aSet.Put(XLineStyleItem(XLINE_NONE));
+                    aSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
 
                     pAktCreate->SetMergedItemSet(aSet);
                 }
@@ -768,9 +768,9 @@ void SdrCreateView::ShowCreateObj(/*OutputDevice* pOut, sal_Bool bFull*/)
             {
                 const SfxItemSet& rSet = pAktCreate->GetMergedItemSet();
                 const drawing::FillStyle eFill(static_cast<const XFillStyleItem&>(rSet.Get(XATTR_FILLSTYLE)).GetValue());
-                const XLineStyle eLine(static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE)).GetValue());
+                const drawing::LineStyle eLine(static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE)).GetValue());
 
-                if(XLINE_NONE == eLine && drawing::FillStyle_NONE == eFill)
+                if(drawing::LineStyle_NONE == eLine && drawing::FillStyle_NONE == eFill)
                 {
                     bUseSolidDragging = false;
                 }
diff --git a/svx/source/svdraw/svdfmtf.cxx b/svx/source/svdraw/svdfmtf.cxx
index 12c19db..a714f9d 100644
--- a/svx/source/svdraw/svdfmtf.cxx
+++ b/svx/source/svdraw/svdfmtf.cxx
@@ -344,12 +344,12 @@ void ImpSdrGDIMetaFileImport::SetAttributes(SdrObject* pObj, bool bForceTextAttr
 
         if(maVD.IsLineColor())
         {
-            mpLineAttr->Put(XLineStyleItem(XLINE_SOLID));
+            mpLineAttr->Put(XLineStyleItem(drawing::LineStyle_SOLID));
             mpLineAttr->Put(XLineColorItem(OUString(), maVD.GetLineColor()));
         }
         else
         {
-            mpLineAttr->Put(XLineStyleItem(XLINE_NONE));
+            mpLineAttr->Put(XLineStyleItem(drawing::LineStyle_NONE));
         }
 
         switch(maLineJoin)
@@ -1080,7 +1080,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaBmpAction& rAct)
     SdrGrafObj* pGraf=new SdrGrafObj(Graphic(rAct.GetBitmap()),aRect);
 
     // This action is not creating line and fill, set directly, do not use SetAttributes(..)
-    pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
     pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
     InsertObj(pGraf);
 }
@@ -1092,7 +1092,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaBmpScaleAction& rAct)
     SdrGrafObj* pGraf=new SdrGrafObj(Graphic(rAct.GetBitmap()),aRect);
 
     // This action is not creating line and fill, set directly, do not use SetAttributes(..)
-    pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
     pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
     InsertObj(pGraf);
 }
@@ -1104,7 +1104,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaBmpExAction& rAct)
     SdrGrafObj* pGraf=new SdrGrafObj( rAct.GetBitmapEx(), aRect );
 
     // This action is not creating line and fill, set directly, do not use SetAttributes(..)
-    pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
     pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
     InsertObj(pGraf);
 }
@@ -1116,7 +1116,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaBmpExScaleAction& rAct)
     SdrGrafObj* pGraf=new SdrGrafObj( rAct.GetBitmapEx(), aRect );
 
     // This action is not creating line and fill, set directly, do not use SetAttributes(..)
-    pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
     pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
     InsertObj(pGraf);
 }
@@ -1250,7 +1250,7 @@ void ImpSdrGDIMetaFileImport::DoAction( MetaCommentAction& rAct, GDIMetaFile& rM
 
                     // switch line off; if there was one there will be a
                     // META_POLYLINE_ACTION following creating another object
-                    aGradAttr.Put(XLineStyleItem(XLINE_NONE));
+                    aGradAttr.Put(XLineStyleItem(drawing::LineStyle_NONE));
 
                     // add detected gradient fillstyle
                     aGradAttr.Put(XFillStyleItem(drawing::FillStyle_GRADIENT));
@@ -1299,7 +1299,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaBmpScalePartAction& rAct)
     SdrGrafObj* pGraf = new SdrGrafObj(aBitmap, aRect);
 
     // This action is not creating line and fill, set directly, do not use SetAttributes(..)
-    pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
     pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
     InsertObj(pGraf);
 }
@@ -1315,7 +1315,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaBmpExScalePartAction& rAct)
     SdrGrafObj* pGraf = new SdrGrafObj(aBitmapEx, aRect);
 
     // This action is not creating line and fill, set directly, do not use SetAttributes(..)
-    pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
     pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
     InsertObj(pGraf);
 }
@@ -1329,7 +1329,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaMaskAction& rAct)
     SdrGrafObj* pGraf = new SdrGrafObj(aBitmapEx, aRect);
 
     // This action is not creating line and fill, set directly, do not use SetAttributes(..)
-    pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
     pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
     InsertObj(pGraf);
 }
@@ -1343,7 +1343,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaMaskScaleAction& rAct)
     SdrGrafObj* pGraf = new SdrGrafObj(aBitmapEx, aRect);
 
     // This action is not creating line and fill, set directly, do not use SetAttributes(..)
-    pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
     pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
     InsertObj(pGraf);
 }
@@ -1358,7 +1358,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaMaskScalePartAction& rAct)
     SdrGrafObj* pGraf = new SdrGrafObj(aBitmapEx, aRect);
 
     // This action is not creating line and fill, set directly, do not use SetAttributes(..)
-    pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+    pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
     pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
     InsertObj(pGraf);
 }
@@ -1679,7 +1679,7 @@ void ImpSdrGDIMetaFileImport::DoAction(MetaFloatTransparentAction& rAct)
             // for MetaFloatTransparentAction, do not use SetAttributes(...)
             // since these metafile content is not used to draw line/fill
             // dependent of these setting at the device content
-            pGraf->SetMergedItem(XLineStyleItem(XLINE_NONE));
+            pGraf->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
             pGraf->SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
             InsertObj(pGraf);
         }
diff --git a/svx/source/svdraw/svdibrow.cxx b/svx/source/svdraw/svdibrow.cxx
index 2694111..1819521 100644
--- a/svx/source/svdraw/svdibrow.cxx
+++ b/svx/source/svdraw/svdibrow.cxx
@@ -614,9 +614,9 @@ bool IsItemIneffective(sal_uInt16 nWhich, const SfxItemSet* pSet, sal_uInt16& rI
         case XATTR_LINETRANSPARENCE : {
             rIndent=1;
             if (ImpGetItem(*pSet,XATTR_LINESTYLE,pItem)) {
-                XLineStyle eLineStyle=static_cast<const XLineStyleItem*>(pItem)->GetValue();
-                if (eLineStyle==XLINE_NONE) return true;
-                if (eLineStyle!=XLINE_DASH && nWhich==XATTR_LINEDASH) return true;
+                drawing::LineStyle eLineStyle=static_cast<const XLineStyleItem*>(pItem)->GetValue();
+                if (eLineStyle==drawing::LineStyle_NONE) return true;
+                if (eLineStyle!=drawing::LineStyle_DASH && nWhich==XATTR_LINEDASH) return true;
             }
             if (nWhich==XATTR_LINESTART || nWhich==XATTR_LINESTARTCENTER) {
                 rIndent=2;
diff --git a/svx/source/svdraw/svdoashp.cxx b/svx/source/svdraw/svdoashp.cxx
index 60910e1..c92aa09 100644
--- a/svx/source/svdraw/svdoashp.cxx
+++ b/svx/source/svdraw/svdoashp.cxx
@@ -235,9 +235,9 @@ SdrObject* ImpCreateShadowObjectClone(const SdrObject& rOriginal, const SfxItemS
 
             if(!bLineUsed)
             {
-                XLineStyle eLineStyle = static_cast<const XLineStyleItem&>(pObj->GetMergedItem(XATTR_LINESTYLE)).GetValue();
+                drawing::LineStyle eLineStyle = static_cast<const XLineStyleItem&>(pObj->GetMergedItem(XATTR_LINESTYLE)).GetValue();
 
-                if(XLINE_NONE != eLineStyle)
+                if(drawing::LineStyle_NONE != eLineStyle)
                 {
                     bLineUsed = true;
                 }
diff --git a/svx/source/svdraw/svdoattr.cxx b/svx/source/svdraw/svdoattr.cxx
index 568322f..36ee5c1 100644
--- a/svx/source/svdraw/svdoattr.cxx
+++ b/svx/source/svdraw/svdoattr.cxx
@@ -144,7 +144,7 @@ sal_Int32 SdrAttrObj::ImpGetLineWdt() const
 {
     sal_Int32 nRetval(0);
 
-    if(XLINE_NONE != static_cast<const XLineStyleItem&>(GetObjectItem(XATTR_LINESTYLE)).GetValue())
+    if(drawing::LineStyle_NONE != static_cast<const XLineStyleItem&>(GetObjectItem(XATTR_LINESTYLE)).GetValue())
     {
         nRetval = static_cast<const XLineWidthItem&>(GetObjectItem(XATTR_LINEWIDTH)).GetValue();
     }
@@ -159,7 +159,7 @@ bool SdrAttrObj::HasFill() const
 
 bool SdrAttrObj::HasLine() const
 {
-    return static_cast<const XLineStyleItem&>(GetProperties().GetObjectItemSet().Get(XATTR_LINESTYLE)).GetValue() != XLINE_NONE;
+    return static_cast<const XLineStyleItem&>(GetProperties().GetObjectItemSet().Get(XATTR_LINESTYLE)).GetValue() != drawing::LineStyle_NONE;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/svx/source/svdraw/svdocirc.cxx b/svx/source/svdraw/svdocirc.cxx
index 1542670..e62175d 100644
--- a/svx/source/svdraw/svdocirc.cxx
+++ b/svx/source/svdraw/svdocirc.cxx
@@ -168,11 +168,11 @@ bool SdrCircObj::PaintNeedsXPolyCirc() const
     if(!bNeed)
     {
         // XPoly is necessary for everything that isn't LineSolid or LineNone
-        XLineStyle eLine = static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE)).GetValue();
-        bNeed = eLine != XLINE_NONE && eLine != XLINE_SOLID;
+        drawing::LineStyle eLine = static_cast<const XLineStyleItem&>(rSet.Get(XATTR_LINESTYLE)).GetValue();
+        bNeed = eLine != drawing::LineStyle_NONE && eLine != drawing::LineStyle_SOLID;
 
         // XPoly is necessary for thick lines
-        if(!bNeed && eLine != XLINE_NONE)
+        if(!bNeed && eLine != drawing::LineStyle_NONE)
             bNeed = static_cast<const XLineWidthItem&>(rSet.Get(XATTR_LINEWIDTH)).GetValue() != 0;
 
         // XPoly is necessary for circle arcs with line ends
diff --git a/svx/source/svdraw/svdograf.cxx b/svx/source/svdraw/svdograf.cxx
index 3e334fc..8dbb3c4 100644
--- a/svx/source/svdraw/svdograf.cxx
+++ b/svx/source/svdraw/svdograf.cxx
@@ -972,7 +972,7 @@ void SdrGrafObj::SetPage( SdrPage* pNewPage )
         else
         {
             SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
-            SetMergedItem(XLineStyleItem(XLINE_NONE));
+            SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
         }
     }
 
diff --git a/svx/source/svdraw/svdoole2.cxx b/svx/source/svdraw/svdoole2.cxx
index 3595305..21896f0 100644
--- a/svx/source/svdraw/svdoole2.cxx
+++ b/svx/source/svdraw/svdoole2.cxx
@@ -1359,7 +1359,7 @@ SdrObject* SdrOle2Obj::createSdrGrafObjReplacement(bool bAddText, bool /* bUseHC
         pClone->SetModel(GetModel());
 
         // gray outline
-        pClone->SetMergedItem(XLineStyleItem(XLINE_SOLID));
+        pClone->SetMergedItem(XLineStyleItem(com::sun::star::drawing::LineStyle_SOLID));
         const svtools::ColorConfig aColorConfig;
         const svtools::ColorConfigValue aColor(aColorConfig.GetColorValue(svtools::OBJECTBOUNDARIES));
         pClone->SetMergedItem(XLineColorItem(OUString(), aColor.nColor));
@@ -1495,7 +1495,7 @@ void SdrOle2Obj::SetPage(SdrPage* pNewPage)
         else
         {
             SetMergedItem(XFillStyleItem(drawing::FillStyle_NONE));
-            SetMergedItem(XLineStyleItem(XLINE_NONE));
+            SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
         }
     }
 
diff --git a/svx/source/svdraw/svdotxtr.cxx b/svx/source/svdraw/svdotxtr.cxx
index 525439c..7ccf903 100644
--- a/svx/source/svdraw/svdotxtr.cxx
+++ b/svx/source/svdraw/svdotxtr.cxx
@@ -368,7 +368,7 @@ SdrObject* SdrTextObj::ImpConvertContainedTextToSdrPathObjs(bool bToPoly) const
                     {
                         // set needed items
                         aAttributeSet.Put(XFillColorItem(OUString(), Color(rCandidate.getBColor())));
-                        aAttributeSet.Put(XLineStyleItem(XLINE_NONE));
+                        aAttributeSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
                         aAttributeSet.Put(XFillStyleItem(drawing::FillStyle_SOLID));
 
                         // create filled SdrPathObj
@@ -378,7 +378,7 @@ SdrObject* SdrTextObj::ImpConvertContainedTextToSdrPathObjs(bool bToPoly) const
                     {
                         // set needed items
                         aAttributeSet.Put(XLineColorItem(OUString(), Color(rCandidate.getBColor())));
-                        aAttributeSet.Put(XLineStyleItem(XLINE_SOLID));
+                        aAttributeSet.Put(XLineStyleItem(drawing::LineStyle_SOLID));
                         aAttributeSet.Put(XLineWidthItem(0));
                         aAttributeSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
 
diff --git a/svx/source/svdraw/svdxcgv.cxx b/svx/source/svdraw/svdxcgv.cxx
index fc4e732..fbc9b53 100644
--- a/svx/source/svdraw/svdxcgv.cxx
+++ b/svx/source/svdraw/svdxcgv.cxx
@@ -152,7 +152,7 @@ bool SdrExchangeView::Paste(const OUString& rStr, const Point& rPos, SdrObjList*
     pObj->SetMergedItemSet(aDefaultAttr);
 
     SfxItemSet aTempAttr(pMod->GetItemPool());  // no fill, no line
-    aTempAttr.Put(XLineStyleItem(XLINE_NONE));
+    aTempAttr.Put(XLineStyleItem(drawing::LineStyle_NONE));
     aTempAttr.Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     pObj->SetMergedItemSet(aTempAttr);
@@ -188,7 +188,7 @@ bool SdrExchangeView::Paste(SvStream& rInput, const OUString& rBaseURL, sal_uInt
     pObj->SetMergedItemSet(aDefaultAttr);
 
     SfxItemSet aTempAttr(pMod->GetItemPool());  // no fill, no line
-    aTempAttr.Put(XLineStyleItem(XLINE_NONE));
+    aTempAttr.Put(XLineStyleItem(drawing::LineStyle_NONE));
     aTempAttr.Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     pObj->SetMergedItemSet(aTempAttr);
diff --git a/svx/source/tbxctrls/colrctrl.cxx b/svx/source/tbxctrls/colrctrl.cxx
index 4022c80..3b79190 100644
--- a/svx/source/tbxctrls/colrctrl.cxx
+++ b/svx/source/tbxctrls/colrctrl.cxx
@@ -389,7 +389,7 @@ IMPL_LINK_NOARG(SvxColorDockingWindow, SelectHdl)
         {
             if( nPos == 1 )     // unsichtbar
             {
-                XLineStyleItem aXLineStyleItem( XLINE_NONE );
+                XLineStyleItem aXLineStyleItem( drawing::LineStyle_NONE );
                 pDispatcher->Execute( nRightSlot, SfxCallMode::RECORD, &aXLineStyleItem, 0L );
             }
             else
@@ -405,11 +405,11 @@ IMPL_LINK_NOARG(SvxColorDockingWindow, SelectHdl)
                         pView->GetAttributes( aAttrSet );
                         if ( aAttrSet.GetItemState( XATTR_LINESTYLE ) != SfxItemState::DONTCARE )
                         {
-                            XLineStyle eXLS = (XLineStyle)
+                            drawing::LineStyle eXLS = (drawing::LineStyle)
                                 static_cast<const XLineStyleItem&>(aAttrSet.Get( XATTR_LINESTYLE ) ).GetValue();
-                            if ( eXLS == XLINE_NONE )
+                            if ( eXLS == drawing::LineStyle_NONE )
                             {
-                                XLineStyleItem aXLineStyleItem( XLINE_SOLID );
+                                XLineStyleItem aXLineStyleItem( drawing::LineStyle_SOLID );
                                 pDispatcher->Execute( nRightSlot, SfxCallMode::RECORD, &aXLineStyleItem, 0L );
                             }
                         }
diff --git a/svx/source/tbxctrls/itemwin.cxx b/svx/source/tbxctrls/itemwin.cxx
index ebc7161..a74bddb 100644
--- a/svx/source/tbxctrls/itemwin.cxx
+++ b/svx/source/tbxctrls/itemwin.cxx
@@ -96,22 +96,22 @@ void SvxLineBox::Select()
 
     if ( !IsTravelSelect() )
     {
-        XLineStyle eXLS;
+        drawing::LineStyle eXLS;
         sal_Int32 nPos = GetSelectEntryPos();
 
         switch ( nPos )
         {
             case 0:
-                eXLS = XLINE_NONE;
+                eXLS = drawing::LineStyle_NONE;
                 break;
 
             case 1:
-                eXLS = XLINE_SOLID;
+                eXLS = drawing::LineStyle_SOLID;
                 break;
 
             default:
             {
-                eXLS = XLINE_DASH;
+                eXLS = drawing::LineStyle_DASH;
 
                 if ( nPos != LISTBOX_ENTRY_NOTFOUND &&
                      SfxObjectShell::Current()  &&
diff --git a/svx/source/tbxctrls/linectrl.cxx b/svx/source/tbxctrls/linectrl.cxx
index 85ead36..de74cd4 100644
--- a/svx/source/tbxctrls/linectrl.cxx
+++ b/svx/source/tbxctrls/linectrl.cxx
@@ -41,6 +41,7 @@ using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::lang;
+using namespace ::com::sun::star;
 
 // For End Line Controlleer
 #define MAX_LINES 12
@@ -129,24 +130,24 @@ void SvxLineStyleToolBoxControl::Update( const SfxPoolItem* pState )
         if( pBox->GetEntryCount() == 0 )
             pBox->FillControl();
 
-        XLineStyle eXLS;
+        drawing::LineStyle eXLS;
 
         if ( pStyleItem )
-            eXLS = ( XLineStyle )pStyleItem->GetValue();
+            eXLS = ( drawing::LineStyle )pStyleItem->GetValue();
         else
-            eXLS = XLINE_NONE;
+            eXLS = drawing::LineStyle_NONE;
 
         switch( eXLS )
         {
-            case XLINE_NONE:
+            case drawing::LineStyle_NONE:
                 pBox->SelectEntryPos( 0 );
                 break;
 
-            case XLINE_SOLID:
+            case drawing::LineStyle_SOLID:
                 pBox->SelectEntryPos( 1 );
                 break;
 
-            case XLINE_DASH:
+            case drawing::LineStyle_DASH:
             {
                 if( pDashItem )
                 {
diff --git a/svx/source/unodraw/UnoGraphicExporter.cxx b/svx/source/unodraw/UnoGraphicExporter.cxx
index ad1be54..b884528 100644
--- a/svx/source/unodraw/UnoGraphicExporter.cxx
+++ b/svx/source/unodraw/UnoGraphicExporter.cxx
@@ -653,7 +653,7 @@ bool GraphicExporter::GetGraphic( ExportSettings& rSettings, Graphic& aGraphic,
             {
                 pTempBackgroundShape = new SdrRectObj(Rectangle(Point(0,0), pPage->GetSize()));
                 pTempBackgroundShape->SetMergedItemSet(pCorrectProperties->GetItemSet());
-                pTempBackgroundShape->SetMergedItem(XLineStyleItem(XLINE_NONE));
+                pTempBackgroundShape->SetMergedItem(XLineStyleItem(drawing::LineStyle_NONE));
                 pTempBackgroundShape->NbcSetStyleSheet(pCorrectProperties->GetStyleSheet(), true);
                 aShapes.push_back(pTempBackgroundShape);
             }
diff --git a/svx/source/unodraw/unoshape.cxx b/svx/source/unodraw/unoshape.cxx
index 81e167d..fc9a127 100644
--- a/svx/source/unodraw/unoshape.cxx
+++ b/svx/source/unodraw/unoshape.cxx
@@ -3103,7 +3103,7 @@ void SvxShape::setAllPropertiesToDefault() throw (uno::RuntimeException, std::ex
     {
         // defaults for graphic objects have changed:
         mpObj->SetMergedItem( XFillStyleItem( drawing::FillStyle_NONE ) );
-        mpObj->SetMergedItem( XLineStyleItem( XLINE_NONE ) );
+        mpObj->SetMergedItem( XLineStyleItem( drawing::LineStyle_NONE ) );
     }
 
     // #i68523# special handling for Svx3DCharacterModeItem, this is not saved
diff --git a/svx/source/xoutdev/xattr.cxx b/svx/source/xoutdev/xattr.cxx
index 6b307c3..fcfc46a 100644
--- a/svx/source/xoutdev/xattr.cxx
+++ b/svx/source/xoutdev/xattr.cxx
@@ -350,7 +350,7 @@ bool XColorItem::PutValue( const ::com::sun::star::uno::Any& rVal, sal_uInt8 /*n
 
 TYPEINIT1_AUTOFACTORY(XLineStyleItem, SfxEnumItem);
 
-XLineStyleItem::XLineStyleItem(XLineStyle eTheLineStyle) :
+XLineStyleItem::XLineStyleItem(com::sun::star::drawing::LineStyle eTheLineStyle) :
     SfxEnumItem(XATTR_LINESTYLE, sal::static_int_cast< sal_uInt16 >(eTheLineStyle))
 {
 }
@@ -384,10 +384,10 @@ bool XLineStyleItem::GetPresentation
 
     switch( (sal_uInt16)GetValue() )
     {
-        case XLINE_NONE:
+        case com::sun::star::drawing::LineStyle_NONE:
             nId = RID_SVXSTR_INVISIBLE;
             break;
-        case XLINE_SOLID:
+        case com::sun::star::drawing::LineStyle_SOLID:
             nId = RID_SVXSTR_SOLID;
             break;
     }
diff --git a/sw/source/filter/ww8/docxattributeoutput.cxx b/sw/source/filter/ww8/docxattributeoutput.cxx
index 4e4dccd..66bc667 100644
--- a/sw/source/filter/ww8/docxattributeoutput.cxx
+++ b/sw/source/filter/ww8/docxattributeoutput.cxx
@@ -124,6 +124,7 @@
 #include <com/sun/star/chart2/XChartDocument.hpp>
 #include <com/sun/star/drawing/ShadingPattern.hpp>
 #include <com/sun/star/text/GraphicCrop.hpp>
+#include <com/sun/star/drawing/LineStyle.hpp>
 
 #include <algorithm>
 
@@ -7692,7 +7693,7 @@ void DocxAttributeOutput::FormatBox( const SvxBoxItem& rBox )
                     AddToAttrList( m_rExport.SdrExporter().getFlyAttrList(), 2,
                             XML_strokecolor, sColor.getStr(),
                             XML_strokeweight, sWidth.getStr() );
-                    if( LineStyle_DASH == pTop->GetBorderLineStyle() ) // Line Style is Dash type
+                    if( drawing::LineStyle_DASH == pTop->GetBorderLineStyle() ) // Line Style is Dash type
                         AddToAttrList( m_rExport.SdrExporter().getDashLineStyle(),
                             XML_dashstyle, "dash" );
                 }
@@ -7707,7 +7708,7 @@ void DocxAttributeOutput::FormatBox( const SvxBoxItem& rBox )
                             XML_val, sColor,
                             FSEND);
                     m_pSerializer->endElementNS(XML_a, XML_solidFill);
-                    if( LineStyle_DASH == pTop->GetBorderLineStyle() ) // Line Style is Dash type
+                    if( drawing::LineStyle_DASH == pTop->GetBorderLineStyle() ) // Line Style is Dash type
                         m_pSerializer->singleElementNS(XML_a, XML_prstDash, XML_val, "dash", FSEND);
                     m_pSerializer->endElementNS(XML_a, XML_ln);
                 }
diff --git a/sw/source/filter/ww8/ww8graf.cxx b/sw/source/filter/ww8/ww8graf.cxx
index 34c5795..ec5564e 100644
--- a/sw/source/filter/ww8/ww8graf.cxx
+++ b/sw/source/filter/ww8/ww8graf.cxx
@@ -205,7 +205,7 @@ static void SetStdAttr( SfxItemSet& rSet, WW8_DP_LINETYPE& rL,
                         WW8_DP_SHADOW& rSh )
 {
     if( SVBT16ToShort( rL.lnps ) == 5 ){            // invisible
-        rSet.Put( XLineStyleItem( XLINE_NONE ) );
+        rSet.Put( XLineStyleItem( drawing::LineStyle_NONE ) );
     }else{                                          // sichtbar
         Color aCol( WW8TransCol( rL.lnpc ) );           // LinienFarbe
         rSet.Put( XLineColorItem( OUString(), aCol ) );
@@ -213,7 +213,7 @@ static void SetStdAttr( SfxItemSet& rSet, WW8_DP_LINETYPE& rL,
                                                     // line thickness
         if( SVBT16ToShort( rL.lnps ) >= 1
             && SVBT16ToShort(rL.lnps ) <= 4 ){      // line style
-            rSet.Put( XLineStyleItem( XLINE_DASH ) );
+            rSet.Put( XLineStyleItem( drawing::LineStyle_DASH ) );
             sal_Int16 nLen = SVBT16ToShort( rL.lnpw );
             XDash aD( XDASH_RECT, 1, 2 * nLen, 1, 5 * nLen, 5 * nLen );
             switch( SVBT16ToShort( rL.lnps ) ){
@@ -227,7 +227,7 @@ static void SetStdAttr( SfxItemSet& rSet, WW8_DP_LINETYPE& rL,
             }
             rSet.Put( XLineDashItem( OUString(), aD ) );
         }else{
-            rSet.Put( XLineStyleItem( XLINE_SOLID ) );  // needed for TextBox
+            rSet.Put( XLineStyleItem( drawing::LineStyle_SOLID ) );  // needed for TextBox
         }
     }
     if( SVBT16ToShort( rSh.shdwpi ) ){                  // shadow
@@ -2720,7 +2720,7 @@ SwFrmFmt* SwWW8ImplReader::MungeTextIntoDrawBox(SdrObject* pTrueObject,
 
         SfxItemSet aSet(pDrawModel->GetItemPool());
         aSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
-        aSet.Put(XLineStyleItem(XLINE_NONE));
+        aSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
         aSet.Put(SdrTextFitToSizeTypeItem( SDRTEXTFIT_NONE ));
         aSet.Put(makeSdrTextAutoGrowHeightItem(false));
         aSet.Put(makeSdrTextAutoGrowWidthItem(false));


More information about the Libreoffice-commits mailing list
diff --git a/svx/source/engine3d/float3d.cxx b/svx/source/engine3d/float3d.cxx
index 742f1f0..b584e5d 100644
--- a/svx/source/engine3d/float3d.cxx
+++ b/svx/source/engine3d/float3d.cxx
@@ -1661,10 +1661,10 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
         // Update preview
         SfxItemSet aSet(rAttrs);
 
         // set LineStyle hard to XLINE_NONE when it's not set so that
         // the default (XLINE_SOLID) is not used for 3d preview
         if(SfxItemState::SET != aSet.GetItemState(XATTR_LINESTYLE, false))
-            aSet.Put(XLineStyleItem(XLINE_NONE));
+            aSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
 
         // set FillColor hard to WHITE when it's SfxItemState::DONTCARE so that
         // the default (Blue7) is not used for 3d preview
@@ -1661,10 +1661,10 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
         SfxItemSet aSet(rAttrs);
 
-        // set LineStyle hard to XLINE_NONE when it's not set so that
-        // the default (XLINE_SOLID) is not used for 3d preview
+        // set LineStyle hard to drawing::LineStyle_NONE when it's not set so that
+        // the default (drawing::LineStyle_SOLID) is not used for 3d preview
         if(SfxItemState::SET != aSet.GetItemState(XATTR_LINESTYLE, false))
diff --git a/svx/source/svdraw/svdedtv2.cxx b/svx/source/svdraw/svdedtv2.cxx
index 93eadf8..f4e7fb2 100644
--- a/svx/source/svdraw/svdedtv2.cxx
+++ b/svx/source/svdraw/svdedtv2.cxx
@@ -1308,16 +1308,16 @@ void SdrEditView::CombineMarkedObjects(bool bNoPolyPoly)
         // attributes of the lowest object
         ImpCopyAttributes(pAttrObj, pPath);
 
-        // If LineStyle of pAttrObj is XLINE_NONE force to XLINE_SOLID to make visible.
-        const XLineStyle eLineStyle = static_cast<const XLineStyleItem&>(pAttrObj->GetMergedItem(XATTR_LINESTYLE)).GetValue();
+        // If LineStyle of pAttrObj is drawing::LineStyle_NONE force to drawing::LineStyle_SOLID to make visible.
+        const drawing::LineStyle eLineStyle = static_cast<const XLineStyleItem&>(pAttrObj->GetMergedItem(XATTR_LINESTYLE)).GetValue();
         const drawing::FillStyle eFillStyle = static_cast<const XFillStyleItem&>(pAttrObj->GetMergedItem(XATTR_FILLSTYLE)).GetValue();
 
         // Take fill style/closed state of pAttrObj in account when deciding to change the line style
         bool bIsClosedPathObj(pAttrObj->ISA(SdrPathObj) && static_cast<const SdrPathObj*>(pAttrObj)->IsClosed());
 
-        if(XLINE_NONE == eLineStyle && (drawing::FillStyle_NONE == eFillStyle || !bIsClosedPathObj))
+        if(drawing::LineStyle_NONE == eLineStyle && (drawing::FillStyle_NONE == eFillStyle || !bIsClosedPathObj))
         {
-            pPath->SetMergedItem(XLineStyleItem(XLINE_SOLID));
+            pPath->SetMergedItem(XLineStyleItem(drawing::LineStyle_SOLID));
         }
 
         SdrInsertReason aReason(SDRREASON_VIEWCALL,pAttrObj);
@@ -1568,7 +1568,7 @@ void SdrEditView::ImpDismantleOneObject(const SdrObject* pObj, SdrObjList& rOL,
                     SfxItemSet aTargetItemSet(pCustomShape->GetMergedItemSet());
 
                     // clear fill and line style
-                    aTargetItemSet.Put(XLineStyleItem(XLINE_NONE));
+                    aTargetItemSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
                     aTargetItemSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
 
                     // get the text bounds and set at text object
diff --git a/svx/source/svdraw/svdobj.cxx b/svx/source/svdraw/svdobj.cxx
index a683ab2..470881f 100644
--- a/svx/source/svdraw/svdobj.cxx
+++ b/svx/source/svdraw/svdobj.cxx
@@ -955,8 +955,8 @@ bool SdrObject::SingleObjectPainter(OutputDevice& rOut) const
 
 bool SdrObject::LineGeometryUsageIsNecessary() const
 {
-    XLineStyle eXLS = (XLineStyle)static_cast<const XLineStyleItem&>(GetMergedItem(XATTR_LINESTYLE)).GetValue();
-    return (eXLS != XLINE_NONE);
+    drawing::LineStyle eXLS = (drawing::LineStyle)static_cast<const XLineStyleItem&>(GetMergedItem(XATTR_LINESTYLE)).GetValue();
+    return (eXLS != drawing::LineStyle_NONE);
 }
 
 SdrObject* SdrObject::Clone() const
@@ -1101,7 +1101,7 @@ basegfx::B2DPolyPolygon SdrObject::TakeContour() const
 {
     basegfx::B2DPolyPolygon aRetval;
 
     // create cloned object without text, but with XLINE_SOLID,
     // COL_BLACK as line color and drawing::FillStyle_NONE
     SdrObject* pClone = Clone();
 
@@ -1144,7 +1144,7 @@ basegfx::B2DPolyPolygon SdrObject::TakeContour() const
         aNewSet.Put(XLineWidthItem(0));
 
         // solid black lines and no fill
-        aNewSet.Put(XLineStyleItem(XLINE_SOLID));
+        aNewSet.Put(XLineStyleItem(drawing::LineStyle_SOLID));
         aNewSet.Put(XLineColorItem(OUString(), Color(COL_BLACK)));
         aNewSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
         pClone->SetMergedItemSet(aNewSet);
@@ -2469,7 +2469,7 @@ SdrObject* SdrObject::ImpConvertToContourObj(SdrObject* pRet, bool bForceLineDas
 
                 // correct item properties
                 aSet.Put(XLineWidthItem(0L));
-                aSet.Put(XLineStyleItem(XLINE_NONE));
+                aSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
                 Color aColorLine = static_cast<const XLineColorItem&>(aSet.Get(XATTR_LINECOLOR)).GetColorValue();
                 sal_uInt16 nTransLine = static_cast<const XLineTransparenceItem&>(aSet.Get(XATTR_LINETRANSPARENCE)).GetValue();
                 aSet.Put(XFillColorItem(OUString(), aColorLine));
@@ -2490,7 +2490,7 @@ SdrObject* SdrObject::ImpConvertToContourObj(SdrObject* pRet, bool bForceLineDas
 
                 aSet.Put(XLineWidthItem(0L));
                 aSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
-                aSet.Put(XLineStyleItem(XLINE_SOLID));
+                aSet.Put(XLineStyleItem(drawing::LineStyle_SOLID));
 
                 // it is also necessary to switch off line start and ends here
                 aSet.Put(XLineStartWidthItem(0));
@@ -2527,7 +2527,7 @@ SdrObject* SdrObject::ImpConvertToContourObj(SdrObject* pRet, bool bForceLineDas
                     // Add a clone of the original geometry.
                     aSet.ClearItem();
                     aSet.Put(pRet->GetMergedItemSet());
-                    aSet.Put(XLineStyleItem(XLINE_NONE));
+                    aSet.Put(XLineStyleItem(drawing::LineStyle_NONE));
                     aSet.Put(XLineWidthItem(0L));
 
                     SdrObject* pClone = pRet->Clone();
@@ -3133,7 +3133,7 @@ bool SdrObject::HasFillStyle() const
 
 bool SdrObject::HasLineStyle() const
 {
-    return static_cast<const XLineStyleItem&>(GetObjectItem(XATTR_LINESTYLE)).GetValue() != XLINE_NONE;
+    return static_cast<const XLineStyleItem&>(GetObjectItem(XATTR_LINESTYLE)).GetValue() != drawing::LineStyle_NONE;
 }
 
 
@@ -1101,7 +1101,7 @@ basegfx::B2DPolyPolygon SdrObject::TakeContour() const
     basegfx::B2DPolyPolygon aRetval;
 
-    // create cloned object without text, but with XLINE_SOLID,
+    // create cloned object without text, but with drawing::LineStyle_SOLID,
     // COL_BLACK as line color and drawing::FillStyle_NONE
     SdrObject* pClone = Clone();